package net.java.dev.csseditor;

import java.awt.event.KeyEvent;

import javax.swing.Action;
import javax.swing.JMenu;
import javax.swing.JMenuBar;
import javax.swing.JMenuItem;
import javax.swing.JSeparator;

import net.java.dev.csseditor.actions.CascadeWindows;
import net.java.dev.csseditor.actions.CloseElementAction;
import net.java.dev.csseditor.actions.NewElementAction;
import net.java.dev.csseditor.actions.ParseElementAction;
import net.java.dev.csseditor.actions.RenameElementAction;
import net.java.dev.csseditor.actions.TileWindows;
import net.java.dev.csseditor.actions.ValidateAction;

/**
 * Creates a menu bar for the editor
 *
 * @author   <a href="mailto:uzi@landsmanns.com">uzi@landsmanns.com</a>
 */
class EditorMenuBar extends JMenuBar {

	private Action newElementAction;
	private Action renameElementAction;
	private Action closeElementAction;
	private Action cascadeWindows;
	private Action tileWindows;
	private Action validateAction;
	private Action parseElementAction;

	private CssEditor cssEditor;
	private JMenu windows;


	/**
	 * Constructor for the EditorMenuBar object
	 *
	 * @param cssEditor  Description of the Parameter
	 */
	public EditorMenuBar(CssEditor cssEditor) {

		newElementAction = new NewElementAction(cssEditor);
		renameElementAction = new RenameElementAction(cssEditor);
		closeElementAction = new CloseElementAction(cssEditor);
		cascadeWindows = new CascadeWindows(cssEditor);
		tileWindows = new TileWindows(cssEditor);
		validateAction = new ValidateAction(cssEditor);
		parseElementAction = new ParseElementAction(cssEditor);

		this.cssEditor = cssEditor;
		JMenu elements = new JMenu("Elements");
		elements.setMnemonic(KeyEvent.VK_L);
		elements.getAccessibleContext().setAccessibleDescription("Manipulate elements");
		add(elements);

		JMenuItem newElement = new JMenuItem("Add new element", KeyEvent.VK_A);
		newElement.setAction(newElementAction);
		newElement.getAccessibleContext().setAccessibleDescription("Add a new element");
		elements.add(newElement);

		JMenuItem closeElement = new JMenuItem("Close element", KeyEvent.VK_C);
		closeElement.setAction(closeElementAction);
		closeElement.getAccessibleContext().setAccessibleDescription("Close element");
		elements.add(closeElement);

		JMenuItem renameElement = new JMenuItem("Rename element", KeyEvent.VK_R);
		renameElement.setAction(renameElementAction);
		renameElement.getAccessibleContext().setAccessibleDescription("Rename element");
		elements.add(renameElement);

		JMenu parsing = new JMenu("Parsing");
		parsing.setMnemonic(KeyEvent.VK_P);
		parsing.getAccessibleContext().setAccessibleDescription("Parsing");
		add(parsing);

		JMenuItem parseElement = new JMenuItem("Parse Current Element", KeyEvent.VK_E);
		parseElement.setAction(parseElementAction);
		parseElement.getAccessibleContext().setAccessibleDescription("Parse Current Element");
		parsing.add(parseElement);

		JMenu validation = new JMenu("Validation");
		validation.setMnemonic(KeyEvent.VK_V);
		validation.getAccessibleContext().setAccessibleDescription("Validation");
		add(validation);

		JMenuItem validateFile = new JMenuItem("Validate File", KeyEvent.VK_F);
		validateFile.setAction(validateAction);
		validateFile.getAccessibleContext().setAccessibleDescription("Validate File");
		validation.add(validateFile);

		windows = new JMenu("Windows");
		windows.setMnemonic(KeyEvent.VK_W);
		windows.getAccessibleContext().setAccessibleDescription("Manipulate windows");
		add(windows);

		JMenuItem cascade = new JMenuItem("Cascade", KeyEvent.VK_C);
		cascade.setAction(cascadeWindows);
		cascade.getAccessibleContext().setAccessibleDescription("Cascade windows");
		windows.add(cascade);

		JMenuItem tile = new JMenuItem("Tile", KeyEvent.VK_T);
		tile.setAction(tileWindows);
		tile.getAccessibleContext().setAccessibleDescription("Tile windows");
		windows.add(tile);

		windows.add(new JSeparator());
	}
	
	public JMenu getWindows() {
		return windows;
	}
}

