package net.java.dev.csseditor;

import java.awt.Dimension;
import java.awt.event.ItemEvent;
import java.awt.event.ItemListener;
import java.awt.Insets;

import java.net.MalformedURLException;
import java.net.URL;

import javax.swing.Icon;
import javax.swing.ImageIcon;
import javax.swing.JButton;
import javax.swing.JComboBox;
import javax.swing.JToolBar;

import net.java.dev.csseditor.actions.CascadeWindows;
import net.java.dev.csseditor.actions.CloseElementAction;
import net.java.dev.csseditor.actions.NewElementAction;
import net.java.dev.csseditor.actions.ParseElementAction;
import net.java.dev.csseditor.actions.RenameElementAction;
import net.java.dev.csseditor.actions.TileWindows;
import net.java.dev.csseditor.actions.ValidateAction;
import net.java.dev.csseditor.tabs.AbstractTabPanel;

import org.gjt.sp.jedit.gui.RolloverButton;

/**
 * Creates a tool bar for the editor
 *
 * @author   <a href="mailto:uzi@landsmanns.com">uzi@landsmanns.com</a>
 */
class EditorToolBar extends JToolBar {

	private CssEditor cssEditor;
	private JComboBox windowsCombo;


	/**
	 * Gets the windowsCombo attribute of the EditorToolBar object
	 *
	 * @return   The windowsCombo value
	 */
	public JComboBox getWindowsCombo() {
		return windowsCombo;
	}


	/**
	 * Constructor for the EditorToolBar object
	 *
	 * @param cssEditor  Description of the Parameter
	 */
	public EditorToolBar(final CssEditor cssEditor) {
		this.cssEditor = cssEditor;

		JButton addButton = prepareButton("Add16.gif");
		addButton.setAction(new NewElementAction(cssEditor, "", addButton.getIcon()));
		addButton.setToolTipText("Add new element");
		add(addButton);

		JButton closeButton = prepareButton("Close16.png");
		closeButton.setAction(new CloseElementAction(cssEditor, "", closeButton.getIcon()));
		closeButton.setToolTipText("Close element");
		add(closeButton);

		JButton renameButton = prepareButton("Rename16.png");
		renameButton.setAction(new RenameElementAction(cssEditor, "", renameButton.getIcon()));
		renameButton.setToolTipText("Rename element");
		add(renameButton);

		addSeparator();

		JButton parseButton = prepareButton("SendMail16.gif");
		parseButton.setAction(new ParseElementAction(cssEditor, "", parseButton.getIcon()));
		parseButton.setToolTipText("Parse element");
		add(parseButton);

		addSeparator();

		JButton validateButton = prepareButton("Properties16.gif");
		validateButton.setAction(new ValidateAction(cssEditor, "", validateButton.getIcon()));
		validateButton.setToolTipText("Validate file");
		add(validateButton);

		addSeparator();

		JButton cascadeButton = prepareButton("cascadeWindows16.gif");
		cascadeButton.setAction(new CascadeWindows(cssEditor, "", cascadeButton.getIcon()));
		cascadeButton.setToolTipText("Cascade windows");
		add(cascadeButton);

		JButton tileButton = prepareButton("tileVertical16.gif");
		tileButton.setAction(new TileWindows(cssEditor, "", tileButton.getIcon()));
		tileButton.setToolTipText("Tile windows");
		add(tileButton);

		windowsCombo = new StyledComboBox(new Object[]{}, "Choose window");
		windowsCombo.setMaximumSize(new Dimension(AbstractTabPanel.MAX_COMBO_WIDTH, AbstractTabPanel.MAX_COMBO_HEIGHT));
		windowsCombo.addItemListener(
			new ItemListener() {
				public void itemStateChanged(ItemEvent ie) {
					if (ie.getStateChange() == ItemEvent.SELECTED) {
						cssEditor.changeFrame("" + ie.getItem());
					}
				}
			});
		add(windowsCombo);
	}


	/**
	 * Creates a button for the toolbar
	 *
	 * @param iconName  the icon file name
	 * @return          a button for the tool bar
	 * @see             org.gjt.sp.jedit.gui.RolloverButton
	 */
	private JButton prepareButton(String iconName) {
		JButton button = new RolloverButton();
		button.setMargin(new Insets(0, 0, 0, 0));

		try {
			Icon icon = new ImageIcon(new URL("jeditresource:CssEditor.jar!icons/" + iconName));
			button.setIcon(icon);
		} catch (MalformedURLException murle) {
			murle.printStackTrace();
		}
		return button;
	}
}

