package net.java.dev.csseditor;

import java.util.Map;
import java.util.TreeMap;

import org.gjt.sp.jedit.textarea.JEditTextArea;
import org.gjt.sp.jedit.textarea.Selection;
import org.gjt.sp.jedit.View;
/**
 * Description of the Class
 *
 * @author   <a href="mailto:uzi@landsmanns.com">uzi@landsmanns.com</a>
 */
public class StyleParser {

	private CssEditor cssEditor;
	private JEditTextArea textArea;
	private int startBracket;
	private int endBracket;
	private String elementName;


	/**
	 * Constructor for the StyleParser object
	 *
	 * @param cssEditor  Description of the Parameter
	 */
	public StyleParser(CssEditor cssEditor) {
		this.cssEditor = cssEditor;
	}


	/**
	 * Constructor for the parseElement object
	 *
	 * @param view  Description of the Parameter
	 */
	public void parseElement(View view) {
		textArea = view.getTextArea();
		int caretPosition = textArea.getCaretPosition();

		parseName();
		parseProperties();

		//textArea.moveCaretPosition(caretPosition);
	}


	/** Description of the Method */
	private void parseName() {

		// check if before any '{'s
		String textBefore = textArea.getText(0, textArea.getCaretPosition());
		if (textBefore.indexOf("{") == -1) {
			return;
		}

		// find previous bracket
		while (true) {
			textArea.goToPrevBracket(false);
			textArea.goToNextCharacter(true);

			// continue until '{' is found
			if (textArea.getSelectedText().equals("{")) {
				break;
			} else {
				textArea.goToPrevCharacter(false);
			}
		}

		textArea.goToPrevCharacter(false);
		startBracket = textArea.getCaretPosition();

		// find the element's name and jump over white space in the end of the name
		while (true) {
			textArea.selectNone();
			textArea.goToPrevCharacter(true);
			char ch = textArea.getSelectedText().charAt(0);
			if (!Character.isWhitespace(ch)) {
				textArea.selectNone();
				break;
			} else {
				textArea.goToPrevCharacter(false);
			}
		}

		// go to start of word
		while (true) {
			textArea.selectNone();
			if (textArea.getCaretPosition() == 0) {
				textArea.selectNone();
				break;
			}
			textArea.goToPrevCharacter(true);
			char ch = textArea.getSelectedText().charAt(0);
			if (Character.isWhitespace(ch)) {
				textArea.selectNone();
				break;
			} else {
				textArea.goToPrevCharacter(false);
			}
		}

		Selection selection = new Selection.Range(textArea.getCaretPosition(), startBracket);
		textArea.addToSelection(selection);
		elementName = textArea.getSelectedText().trim();
	}


	/** Description of the Method */
	private void parseProperties() {
		textArea.moveCaretPosition(startBracket);
		textArea.selectNone();
		textArea.goToNextCharacter(true);
		textArea.goToMatchingBracket();
		endBracket = textArea.getCaretPosition();
		Selection brackets = new Selection.Range(startBracket, endBracket);
		//textArea.addToSelection(brackets);
		String propString = textArea.getSelectedText(brackets);
		propString = propString.substring(1, propString.length() - 1).trim();
		String[] strings = propString.split(";");
		Map props = new TreeMap();
		for (int i = 0; i < strings.length; i++) {
			String str = strings[i].trim();
			int col = str.indexOf(":");
			String key = str.substring(0, col).trim();
			String value = str.substring(col + 1).trim();
			props.put(key, value);
		}
		cssEditor.createNewFrame(elementName, props);
	}
}

