package net.java.dev.csseditor;

import java.awt.Color;
import java.awt.Dimension;

import javax.swing.JComboBox;
import javax.swing.JScrollPane;
import javax.swing.JToolTip;
import javax.swing.plaf.basic.BasicComboBoxUI;
import javax.swing.plaf.basic.BasicComboPopup;
import javax.swing.plaf.basic.ComboPopup;
import javax.swing.ScrollPaneConstants;

/**
 * A special <code>JComboBox</code>, which allows horizontal scrolls when
 * needed. Adapted after articles found in Sun's Java forums.
 *
 * @author   <a href="mailto:uzi@landsmanns.com">Uzi Landsmann</a>
 * @see      <a href="http://bugs.sun.com/bugdatabase/view_bug.do?bug_id=4880218">
 *      Bug 4880218</a>
 * @see      <a href="http://forum.java.sun.com/thread.jsp?forum=57&thread=206828">
 *      Java Forums - JComboBox popup size problems when adding horizontal
 *      scrollbar</a>
 */
public class StyledComboBox extends JComboBox {

	private String tooltip;


	/**
	 * Constructor for the StyledComboBox object
	 *
	 * @param list     Description of the Parameter
	 * @param tooltip  Description of the Parameter
	 */
	public StyledComboBox(Object[] list, String tooltip) {
		super(list);
		this.tooltip = tooltip;
		setUI(new StyledComboBoxUI());
		getEditor().getEditorComponent().setBackground(Color.lightGray);
		setEditable(true);
		setToolTipText(tooltip);
	}

	/**
	 * Description of the Class
	 *
	 * @author   <a href="mailto:uzi@landsmanns.com">Uzi Landsmann</a>
	 */
	class StyledComboBoxUI extends BasicComboBoxUI {
		/**
		 * Description of the Method
		 *
		 * @return   Description of the Return Value
		 */
		protected ComboPopup createPopup() {
			BasicComboPopup popup = new StyledComboPopup(comboBox);
			popup.getAccessibleContext().setAccessibleParent(comboBox);

			return popup;
		}
	}


	/**
	 * Description of the Class
	 *
	 * @author   <a href="mailto:uzi@landsmanns.com">Uzi Landsmann</a>
	 */
	class StyledComboPopup extends BasicComboPopup {
		/**
		 * Constructor for the StyledComboPopup object
		 *
		 * @param comboBox  Description of the Parameter
		 */
		public StyledComboPopup(JComboBox comboBox) {
			super(comboBox);
		}


		/**
		 * Description of the Method
		 *
		 * @return   Description of the Return Value
		 */
		public JScrollPane createScroller() {
			return new JScrollPane(list, ScrollPaneConstants.VERTICAL_SCROLLBAR_AS_NEEDED, ScrollPaneConstants.HORIZONTAL_SCROLLBAR_AS_NEEDED);
		}


		/**
		 * Gets the popupHeightForRowCount attribute of the StyledComboPopup object
		 *
		 * @param maxRowCount  Description of the Parameter
		 * @return             The popupHeightForRowCount value
		 */
		protected int getPopupHeightForRowCount(int maxRowCount) {
			int n = super.getPopupHeightForRowCount(maxRowCount);
			n += (int) scroller.getHorizontalScrollBar().getMaximumSize().getHeight();
			return n;
		}
	}
}


