package net.java.dev.csseditor;

import java.io.FileInputStream;
import java.io.FileNotFoundException;

import java.net.MalformedURLException;
import java.net.URL;

import org.w3c.css.css.StyleSheet;
import org.w3c.css.css.StyleSheetCom;
import org.w3c.css.css.StyleSheetOrigin;
import org.w3c.css.css.StyleSheetParser;
import org.w3c.css.util.ApplContext;

/**
 * This class allows using the W3C css validator to validate the quality of the
 * current css file opened in jEdit's current buffer. Any errors or warnings are
 * shown using the jEdit ErrorList plugin.
 *
 * @author   <a href="mailto:uzi@landsmanns.com">Uzi Landsmann</a>
 * @see      <a href="http://jigsaw.w3.org/css-validator/validator-uri.html">W3C
 *      Css Validator</a>
 * @see      <a href="http://plugins.jedit.org/plugins/?ErrorList">Error List
 *      Plugin</a>
 */
public abstract class Validator extends StyleSheetCom {

	/** Description of the Method */
	protected abstract void init();


	/** Description of the Method */
	protected abstract void uninit();


	/**
	 * Report any errors or warnings found while validating a file.
	 *
	 * @param fileName  the validated file
	 * @param style     the W3C stylesheet element which was validated
	 */
	protected abstract void reportErrors(String fileName, StyleSheet style);


	/**
	 * Validate the current css file using the W3C Css Validator and show any
	 * errors or warnings using the jEdit Error List Plugin
	 *
	 * @param fileName  The file to validate
	 */
	public void val(String fileName) {
		init();
		try {
			ApplContext ac = new ApplContext("en");
			URL url = new URL("file", "/", fileName);
			System.err.println("url:" + url);
			String title = "title";
			String kind = "stylesheet";
			String media = null;

			StyleSheetParser parser = new StyleSheetParser();
			parser.parseURL(ac, url, title, kind, media, StyleSheetOrigin.AUTHOR);
			StyleSheet style = parser.getStyleSheet();
			reportErrors(fileName, style);
		} catch (MalformedURLException murle) {
			murle.printStackTrace();
		} finally {
			uninit();
		}
	}


	/**
	 * Validate a current row in a given file, not used
	 *
	 * @param fileName  the file to validate
	 * @param lineNo    the row to validate
	 */
	public void val(String fileName, int lineNo) {
		init();
		try {
			ApplContext ac = new ApplContext("en");
			FileInputStream fis = new FileInputStream(fileName);
			URL url = new URL("file", "/", fileName);
			String title = "title";
			String kind = "stylesheet";
			String media = null;

			StyleSheetParser parser = new StyleSheetParser();
			parser.parseStyleElement(ac, fis, title, media, url, lineNo);
			StyleSheet style = parser.getStyleSheet();
			reportErrors(fileName, style);
		} catch (MalformedURLException murle) {
			murle.printStackTrace();
		} catch (FileNotFoundException fnfe) {
			fnfe.printStackTrace();
		} finally {
			uninit();
		}
	}
}


