package net.java.dev.csseditor.actions;

import java.awt.event.ActionEvent;

import java.beans.PropertyVetoException;

import javax.swing.AbstractAction;
import javax.swing.Icon;
import javax.swing.JDesktopPane;
import javax.swing.JInternalFrame;

import net.java.dev.csseditor.CssEditor;

/**
 * An <code>Action</code> which allows cascading all windows
 *
 * @author   <a href="mailto:uzi@landsmanns.com">uzi@landsmanns.com</a>
 */
public class CascadeWindows extends AbstractAction {

	private CssEditor cssEditor;


	/**
	 * Constructor for the CloseElementAction object
	 *
	 * @param cssEditor  Description of the Parameter
	 */
	public CascadeWindows(CssEditor cssEditor) {
		super("Cascade windows");
		this.cssEditor = cssEditor;
	}


	/**
	 * Constructor for the CascadeWindows object
	 *
	 * @param description  Description of the Parameter
	 * @param icon         Description of the Parameter
	 * @param cssEditor    Description of the Parameter
	 */
	public CascadeWindows(CssEditor cssEditor, String description, Icon icon) {
		super(description, icon);
		this.cssEditor = cssEditor;
	}



	/**
	 * Cascade all windows
	 *
	 * @param ae  the action event
	 */
	public void actionPerformed(ActionEvent ae) {
		JDesktopPane desktop = cssEditor.getDesktop();
		JInternalFrame[] frames = desktop.getAllFrames();
		if (frames.length == 0) {
			return;
		}
		JInternalFrame iframe = frames[0];
		int frameDistance = frameDistance = iframe.getHeight() - iframe.getContentPane().getHeight();
		int x = 0;
		int y = 0;
		int width = desktop.getWidth() / 2;
		int height = desktop.getHeight() / 2;
		for (int i = 0; i < frames.length; i++) {
			if (!frames[i].isIcon()) {
				try {
					frames[i].setMaximum(false);
					frames[i].reshape(x, y, width, height);
					x += frameDistance;
					y += frameDistance;
					if (x + width > desktop.getWidth()) {
						x = 0;
					}
					if (y + height > desktop.getHeight()) {
						y = 0;
					}
				} catch (PropertyVetoException pve) {
					pve.printStackTrace();
				}
			}
		}
	}
}

