package net.java.dev.csseditor.actions;

import java.awt.event.ActionEvent;

import java.beans.PropertyVetoException;

import javax.swing.AbstractAction;
import javax.swing.Icon;
import javax.swing.JDesktopPane;
import javax.swing.JInternalFrame;

import net.java.dev.csseditor.CssEditor;

/**
 * An <code>Action</code> which allows tiling all windows
 *
 * @author   <a href="mailto:uzi@landsmanns.com">uzi@landsmanns.com</a>
 */
public class TileWindows extends AbstractAction {

	private CssEditor cssEditor;


	/**
	 * Constructor for the TileWindows object
	 *
	 * @param cssEditor  Description of the Parameter
	 */
	public TileWindows(CssEditor cssEditor) {
		super("Tile Windows");
		this.cssEditor = cssEditor;
	}


	/**
	 * Constructor for the TileWindows object
	 *
	 * @param description  Description of the Parameter
	 * @param icon         Description of the Parameter
	 * @param cssEditor    Description of the Parameter
	 */
	public TileWindows(CssEditor cssEditor, String description, Icon icon) {
		super(description, icon);
		this.cssEditor = cssEditor;
	}


	/**
	 * Tile all windows
	 *
	 * @param ae  the action event
	 */
	public void actionPerformed(ActionEvent ae) {
		JDesktopPane desktop = cssEditor.getDesktop();
		JInternalFrame[] frames = desktop.getAllFrames();
		int frameCount = 0;
		for (int i = 0; i < frames.length; i++) {
			if (!frames[i].isIcon()) {
				frameCount++;
			}
		}
		int rows = (int) Math.sqrt(frameCount);
		int cols = frameCount / rows;
		int extra = frameCount % rows;
		int width = desktop.getWidth() / cols;
		int height = desktop.getHeight() / rows;
		int r = 0;
		int c = 0;
		for (int i = 0; i < frames.length; i++) {
			if (!frames[i].isIcon()) {
				try {
					frames[i].setMaximum(false);
					frames[i].reshape(c * width, r * height, width, height);
					r++;
					if (r == rows) {
						r = 0;
						c++;
						if (c == cols - extra) {
							rows++;
							height = desktop.getHeight() / rows;
						}
					}
				} catch (PropertyVetoException pve) {
					pve.printStackTrace();
				}
			}
		}
	}
}

