package net.java.dev.csseditor.choosers;

import java.awt.BorderLayout;
import java.awt.Dimension;
import java.awt.event.ActionEvent;
import java.awt.event.ActionListener;

import java.io.File;

import javax.swing.BoxLayout;
import javax.swing.JButton;
import javax.swing.JFileChooser;
import javax.swing.JPanel;
import javax.swing.JTextField;

/**
 * Description of the Class
 *
 * @author   <a href="mailto:uzi@landsmanns.com">Uzi Landsmann</a>
 */
public class FileChooserField extends JPanel {

	private JTextField textField;
	private JButton button = new JButton("file...");


	/**
	 * Constructor for the FileChooserField object
	 *
	 * @param fieldWidth    Description of the Parameter
	 * @param buttonWidth   Description of the Parameter
	 * @param buttonHeight  Description of the Parameter
	 */
	public FileChooserField(int fieldWidth, int buttonWidth, int buttonHeight) {
		setLayout(new BoxLayout(this, BoxLayout.Y_AXIS));

		textField = new JTextField(fieldWidth);
		button.setPreferredSize(new Dimension(buttonWidth, buttonHeight));
		button.addActionListener(new ButtonListener());

		JPanel textPanel = new JPanel(new BorderLayout());
		textPanel.add(textField, BorderLayout.CENTER);

		JPanel buttonPanel = new JPanel(new BorderLayout());
		buttonPanel.add(button, BorderLayout.EAST);

		add(textPanel);
		add(buttonPanel);
	}


	/** Description of the Method */
	public void clear() {
		textField.setText("");
	}


	/**
	 * Gets the text attribute of the FileChooserField object
	 *
	 * @return   The text value
	 */
	public String getText() {
		return textField.getText();
	}


	/**
	 * Sets the enabled attribute of the FileChooserField object
	 *
	 * @param boo  The new enabled value
	 */
	public void setEnabled(boolean boo) {
		textField.setEnabled(boo);
		button.setEnabled(boo);
	}


	/**
	 * Description of the Class
	 *
	 * @author   <a href="uzi@landsmanns.com">Uzi Landsmann</a>
	 */
	class ButtonListener implements ActionListener {
		private JFileChooser chooser = new JFileChooser();


		/**
		 * Description of the Method
		 *
		 * @param ae  Description of the Parameter
		 */
		public void actionPerformed(ActionEvent ae) {
			int returnCode = chooser.showOpenDialog(null);

			if (returnCode == JFileChooser.APPROVE_OPTION) {
				File file = chooser.getSelectedFile();
				textField.setText("url(file:///" + file.getAbsolutePath() + ")");
			}
		}
	}
}

