package net.java.dev.csseditor.choosers;

import java.awt.BorderLayout;
import java.awt.Dimension;
import java.awt.event.ActionEvent;
import java.awt.event.ActionListener;
import java.awt.FlowLayout;

import java.util.Enumeration;

import javax.swing.Box;
import javax.swing.BoxLayout;
import javax.swing.DefaultListModel;
import javax.swing.JButton;
import javax.swing.JLabel;
import javax.swing.JList;
import javax.swing.JPanel;
import javax.swing.JScrollPane;

import net.java.dev.csseditor.listeners.AbstractListener;
import net.java.dev.csseditor.tabs.Font;

/**
 * Description of the Class
 *
 * @author   <a href="mailto:uzi@landsmanns.com">Uzi Landsmann</a>
 */
public class FontChooser extends AbstractChooser {

	private DefaultListModel leftModel = new DefaultListModel();
	private DefaultListModel rightModel = new DefaultListModel();
	private JList left, right;
	private JPanel panel = new JPanel();


	/**
	 * Constructor for the SizeChooser object
	 *
	 * @param listener  Description of the Parameter
	 * @param title     Description of the Parameter
	 */
	public FontChooser(final AbstractListener listener, String title) {
		super(listener, null, title, true);

		getContentPane().setLayout(new BorderLayout());

		JPanel buttons = new JPanel();

		panel.setLayout(new FlowLayout(FlowLayout.CENTER));

		String[] fonts = Font.getFontFamilyNames();
		for (int i = 0; i < fonts.length; i++) {
			leftModel.addElement(fonts[i]);
		}

		left = new JList(leftModel);
		right = new JList(rightModel);

		left.setVisibleRowCount(10);
		right.setVisibleRowCount(10);

		JPanel moveSidePanel = new JPanel();
		moveSidePanel.setLayout(new BoxLayout(moveSidePanel, BoxLayout.Y_AXIS));

		JButton toRight = new JButton("->");
		JButton toLeft = new JButton("<-");

		toRight.setActionCommand("right");
		toLeft.setActionCommand("left");

		ButtonListener bl = new ButtonListener();

		toRight.addActionListener(bl);
		toLeft.addActionListener(bl);

		moveSidePanel.add(Box.createRigidArea(new Dimension(10, 20)));
		moveSidePanel.add(toRight);
		moveSidePanel.add(toLeft);
		moveSidePanel.add(Box.createRigidArea(new Dimension(10, 20)));

		JPanel moveUpDownPanel = new JPanel();
		moveUpDownPanel.setLayout(new BoxLayout(moveUpDownPanel, BoxLayout.Y_AXIS));

		JButton toUpp = new JButton("+");
		JButton toDown = new JButton("-");

		toUpp.setActionCommand("upp");
		toDown.setActionCommand("down");

		toUpp.addActionListener(bl);
		toDown.addActionListener(bl);

		moveUpDownPanel.add(Box.createRigidArea(new Dimension(10, 20)));
		moveUpDownPanel.add(toUpp);
		moveUpDownPanel.add(toDown);
		moveUpDownPanel.add(Box.createRigidArea(new Dimension(10, 20)));

		panel.add(new JScrollPane(left));
		panel.add(moveSidePanel);
		panel.add(new JScrollPane(right));
		panel.add(moveUpDownPanel);

		JButton okButton = new JButton("Ok");
		JButton cancelButton = new JButton("Cancel");

		okButton.setActionCommand("ok");
		cancelButton.setActionCommand("cancel");

		okButton.addActionListener(bl);
		cancelButton.addActionListener(bl);

		buttons.add(okButton);
		buttons.add(cancelButton);

		getContentPane().add(panel, BorderLayout.NORTH);
		getContentPane().add(new JLabel(" "), BorderLayout.CENTER);
		getContentPane().add(buttons, BorderLayout.SOUTH);

		pack();
	}


	/**
	 * Description of the Class
	 *
	 * @author   <a href="uzi@landsmanns.com">Uzi Landsmann</a>
	 */
	class ButtonListener implements ActionListener {

		/**
		 * Description of the Method
		 *
		 * @param e  Description of the Parameter
		 */
		public void actionPerformed(ActionEvent e) {
			String which = e.getActionCommand();
			if (which.equals("right")) {
				Object[] objects = left.getSelectedValues();
				for (int i = 0; i < objects.length; i++) {
					leftModel.removeElement(objects[i]);
					rightModel.addElement(objects[i]);
				}
			} else if (which.equals("left")) {
				Object[] objects = right.getSelectedValues();
				for (int i = 0; i < objects.length; i++) {
					rightModel.removeElement(objects[i]);
					leftModel.addElement(objects[i]);
				}
			} else if (which.equals("upp")) {
				int[] selected = right.getSelectedIndices();
				if (selected.length == 1 && selected[0] > 0) {
					Object obj = rightModel.remove(selected[0] - 1);
					rightModel.add(selected[0], obj);
				}
			} else if (which.equals("down")) {
				int[] selected = right.getSelectedIndices();
				if (selected.length == 1 && selected[0] < rightModel.getSize()) {
					Object obj = rightModel.remove(selected[0] + 1);
					rightModel.add(selected[0], obj);
				}
			} else if (which.equals("ok")) {
				Enumeration enume = rightModel.elements();
				String[] strings = new String[rightModel.getSize()];
				int i = 0;
				while (enume.hasMoreElements()) {
					strings[i++] = (String) enume.nextElement();
				}
				listener.setValues(strings);
				setVisible(false);
				dispose();
			} else {
				listener.resetValues();
				setVisible(false);
				dispose();
			}
		}
	}
}


