package net.java.dev.csseditor.choosers;

import java.awt.BorderLayout;
import java.awt.Dimension;
import java.awt.event.ActionEvent;
import java.awt.event.ActionListener;
import java.awt.FlowLayout;

import javax.swing.Box;
import javax.swing.BoxLayout;
import javax.swing.JButton;
import javax.swing.JComboBox;
import javax.swing.JLabel;
import javax.swing.JPanel;
import javax.swing.JSpinner;

import net.java.dev.csseditor.listeners.AbstractListener;

/**
 * Description of the Class
 *
 * @author   <a href="mailto:uzi@landsmanns.com">Uzi Landsmann</a>
 */
public class ShapeChooser extends AbstractChooser {
	private JSpinner positionSpinnerTop = new JSpinner();
	private JSpinner positionSpinnerBottom = new JSpinner();
	private JSpinner positionSpinnerLeft = new JSpinner();
	private JSpinner positionSpinnerRight = new JSpinner();

	private JComboBox positionUnitTop = new JComboBox(unitList);
	private JComboBox positionUnitBottom = new JComboBox(unitList);
	private JComboBox positionUnitLeft = new JComboBox(unitList);
	private JComboBox positionUnitRight = new JComboBox(unitList);


	/**
	 * Constructor for the SizeChooser object
	 *
	 * @param listener  Description of the Parameter
	 * @param title     Description of the Parameter
	 */
	public ShapeChooser(final AbstractListener listener, String title) {
		super(listener, null, title, true);

		getContentPane().setLayout(new BorderLayout());

		JPanel panel = new JPanel();
		JPanel positionX = new JPanel(new FlowLayout(FlowLayout.LEFT));
		JPanel positionY = new JPanel(new FlowLayout(FlowLayout.LEFT));
		JPanel buttons = new JPanel();

		panel.setLayout(new BoxLayout(panel, BoxLayout.Y_AXIS));

		positionSpinnerTop.setPreferredSize(new Dimension(50, 20));
		positionSpinnerBottom.setPreferredSize(new Dimension(50, 20));
		positionSpinnerLeft.setPreferredSize(new Dimension(50, 20));
		positionSpinnerRight.setPreferredSize(new Dimension(50, 20));

		positionX.add(Box.createRigidArea(new Dimension(17, 0)));
		positionX.add(new JLabel("top:"));
		positionX.add(positionSpinnerTop);
		positionX.add(positionUnitTop);
		positionX.add(Box.createRigidArea(new Dimension(17, 0)));
		positionX.add(new JLabel("left:"));
		positionX.add(positionSpinnerLeft);
		positionX.add(positionUnitLeft);

		positionY.add(new JLabel("bottom:"));
		positionY.add(positionSpinnerBottom);
		positionY.add(positionUnitBottom);
		positionY.add(Box.createRigidArea(new Dimension(10, 0)));
		positionY.add(new JLabel("right:"));
		positionY.add(positionSpinnerRight);
		positionY.add(positionUnitRight);

		positionUnitTop.setSelectedItem("px");
		positionUnitBottom.setSelectedItem("px");
		positionUnitLeft.setSelectedItem("px");
		positionUnitRight.setSelectedItem("px");

		JButton okButton = new JButton("Ok");
		JButton cancelButton = new JButton("Cancel");

		okButton.setActionCommand("ok");
		cancelButton.setActionCommand("cancel");

		ButtonListener bl = new ButtonListener();

		okButton.addActionListener(bl);
		cancelButton.addActionListener(bl);

		buttons.add(okButton);
		buttons.add(cancelButton);

		panel.add(positionX);
		panel.add(positionY);
		getContentPane().add(panel, BorderLayout.NORTH);
		getContentPane().add(new JLabel(" "), BorderLayout.CENTER);
		getContentPane().add(buttons, BorderLayout.SOUTH);

		pack();
	}


	/**
	 * Description of the Class
	 *
	 * @author   <a href="uzi@landsmanns.com">Uzi Landsmann</a>
	 */
	class ButtonListener implements ActionListener {

		// todo: check if order is top-left-bootm-right
		/**
		 * Description of the Method
		 *
		 * @param e  Description of the Parameter
		 */
		public void actionPerformed(ActionEvent e) {
			String which = e.getActionCommand();
			if (which.equals("ok")) {
				listener.setValues(positionSpinnerTop.getValue(),
						positionUnitTop.getSelectedItem(),
						positionSpinnerLeft.getValue(),
						positionUnitLeft.getSelectedItem(),
						positionSpinnerBottom.getValue(),
						positionUnitBottom.getSelectedItem(),
						positionSpinnerRight.getValue(),
						positionUnitRight.getSelectedItem());
			} else {
				listener.resetValues();
			}

			setVisible(false);
			dispose();
		}
	}
}


