package net.java.dev.csseditor.jedit;

import java.util.Iterator;
import java.util.Map;
import java.util.Set;

import net.java.dev.csseditor.TextWriter;

import org.gjt.sp.jedit.buffer.JEditBuffer;
import org.gjt.sp.jedit.textarea.JEditTextArea;
import org.gjt.sp.jedit.View;

/**
 * A class that allows writing css elements in the text buffer
 *
 * @author   <a href="mailto:uzi@landsmanns.com">Uzi Landsmann</a>
 */
public class JEditTextWriter implements TextWriter {
	private JEditTextArea area;


	/**
	 * Constructor for the TextWriter object
	 *
	 * @param view  jEdit's current view
	 */
	public JEditTextWriter(View view) {
		area = view.getTextArea();
	}


	/**
	 * Writes a css element in the current buffer in the caret's current position
	 *
	 * @param name   the element's name
	 * @param props  the list of css properties and their values
	 */
	public void writeNewStyleItem(String name, Map props) {
		Set keys = props.keySet();
		Iterator iter = keys.iterator();

		String text = name + " {\n";
		while (iter.hasNext()) {
			String key = (String) iter.next();
			String value = (String) props.get(key);
			text += "\t" + key + ": " + value + ";\n";
		}
		text += "}";

		JEditBuffer buffer = area.getBuffer();

		String bufferText = buffer.getText(0, buffer.getLength());
		int i = bufferText.indexOf(name);
		int start;

		try {
			buffer.beginCompoundEdit();

			if (i == -1) {
				start = area.getCaretPosition();
			} else {
				start = i;
				int closingBracket = bufferText.indexOf("}", i);
				if (closingBracket != -1) {
					buffer.remove(start, closingBracket - start + 1);
				}
			}
			buffer.insert(start, text);
		} finally {
			buffer.endCompoundEdit();
		}
	}
}

