package net.java.dev.csseditor.jedit;

import errorlist.DefaultErrorSource;
import errorlist.ErrorSource;

import net.java.dev.csseditor.CssEditor;
import net.java.dev.csseditor.Validator;

import org.gjt.sp.jedit.gui.DockableWindowManager;
import org.gjt.sp.jedit.View;

import org.w3c.css.css.StyleSheet;
import org.w3c.css.parser.CssError;
import org.w3c.css.util.Warning;

/**
 * This class allows using the W3C css validator to validate the quality of the
 * current css file opened in jEdit's current buffer. Any errors or warnings are
 * shown using the jEdit ErrorList plugin.
 *
 * @author   <a href="mailto:uzi@landsmanns.com">Uzi Landsmann</a>
 * @see      <a href="http://jigsaw.w3.org/css-validator/validator-uri.html">W3C
 *      Css Validator</a>
 * @see      <a href="http://plugins.jedit.org/plugins/?ErrorList">Error List
 *      Plugin</a>
 */
public class JEditValidator extends Validator {

	private static DefaultErrorSource errorSource = new DefaultErrorSource("Css Validator");


	/** Register the css editor plugin in the error list plugin */
	protected void init() {
		DefaultErrorSource.registerErrorSource(errorSource);
		errorSource.clear();
	}


	/** Unregister the css editor plugin in the error list plugin */
	public void uninit() {
		DefaultErrorSource.unregisterErrorSource(errorSource);
	}


	/**
	 * Report any errors or warnings found while validating a file using the Error
	 * List Plugin.
	 *
	 * @param fileName  the validated file
	 * @param style     the W3C stylesheet element which was validated
	 */
	public void reportErrors(String fileName, StyleSheet style) {
		CssError[] errors = style.getErrors().getErrors();
		Warning[] warnings = style.getWarnings().getWarnings();

		for (int i = 0; i < errors.length; i++) {
			CssError cssError = errors[i];
			DefaultErrorSource.DefaultError error = new DefaultErrorSource.DefaultError(
					errorSource, ErrorSource.ERROR, fileName, cssError.getLine() - 1,
					0, 0, cssError.getException().getMessage());
			errorSource.addError(error);
		}

		for (int i = 0; i < warnings.length; i++) {
			Warning cssWarning = warnings[i];
			DefaultErrorSource.DefaultError warning = new DefaultErrorSource.DefaultError(
					errorSource, ErrorSource.WARNING, fileName, cssWarning.getLine() - 1,
					0, 0, cssWarning.getWarningMessage());
			errorSource.addError(warning);
		}

		showErrorList();
	}


	/** Show the Error List plugin */
	private void showErrorList() {
		View view = CssEditor.getView();
		DockableWindowManager mgr = view.getDockableWindowManager();
		String el = "error-list";
		if (mgr.getDockable(el) == null) {
			mgr.addDockableWindow(el);
		}
		mgr.showDockableWindow(el);
	}
}


