package net.java.dev.csseditor.listeners;

import java.awt.Color;
import java.awt.event.ActionEvent;

import javax.swing.JColorChooser;
import javax.swing.JComboBox;

import net.java.dev.csseditor.tabs.AbstractTabPanel;

/**
 * A Listener to Color <code>JComboBox</code> events. The <code>actionPerformed</code>
 * method is generated only when the user chooses a special value in the <code>JComboBox</code>
 * . When this happens, this class will pop-up a <code>JColorChooser</code> to
 * choose values from.
 *
 * @author   <a href="mailto:uzi@landsmanns.com">Uzi Landsmann</a>
 * @see      JColorChooser
 */
public class ColorListener extends AbstractListener {

	/**
	 * Constructor for the <code>ColorListener</code> object
	 *
	 * @param owner  The <code>JPanel</code> which uses this listener
	 * @param title  The <code>Chooser</code>'s title
	 * @param word   The value that this listener is waiting for
	 */
	public ColorListener(AbstractTabPanel owner, String title, String word) {
		super(owner, title, word);
	}


	/**
	 * Called when a user chooses a specific value in the <code>JComboBox</code>
	 * that this class listens to
	 *
	 * @param ae  The generated <code>ActionEvent</code>
	 */
	public void actionPerformed(ActionEvent ae) {
		JComboBox combo = (JComboBox) ae.getSource();
		String line = (String) combo.getSelectedItem();
		Color chosenColor;
		if (line.equals(word)) {
			chosenColor = JColorChooser.showDialog(null, title, Color.black);
			if (chosenColor != null) {
				String red = Integer.toHexString(chosenColor.getRed());
				String green = Integer.toHexString(chosenColor.getGreen());
				String blue = Integer.toHexString(chosenColor.getBlue());

				if (red.length() < 2) {
					red = "0" + red;
				}
				if (green.length() < 2) {
					green = "0" + green;
				}
				if (blue.length() < 2) {
					blue = "0" + blue;
				}

				String rgb = "#" + red + green + blue;

				combo.addItem(rgb);
				combo.setSelectedItem(rgb);
			} else {
				combo.setSelectedItem(null);
			}
			updatePreview();
		}
	}
}

