package net.java.dev.csseditor.listeners;

import java.awt.event.ActionEvent;

import javax.swing.JComboBox;

import net.java.dev.csseditor.choosers.FontChooser;
import net.java.dev.csseditor.tabs.AbstractTabPanel;

/**
 * A <code>Listener</code> that allows showing a specific chooser when the user
 * is choosing a specific word in a <code>Combobox</code> A Listener to font
 * <code>JComboBox</code> events. The <code>actionPerformed</code> method is
 * generated only when the user chooses a special value in the <code>JComboBox</code>
 * . When this happens, this class will pop-up a <code>FontChooser</code> to
 * choose values from.
 *
 * @author   <a href="mailto:uzi@landsmanns.com">Uzi Landsmann</a>
 * @see      net.java.dev.csseditor.choosers.FontChooser
 */
public class FontListener extends AbstractListener {

	/**
	 * Constructor for the <code>FontListener</code> object
	 *
	 * @param owner  The <code>JPanel</code> which uses this listener
	 * @param title  The <code>Chooser</code>'s title
	 * @param word   The value that this listener is waiting for
	 */
	public FontListener(AbstractTabPanel owner, String title, String word) {
		super(owner, title, word);
	}


	/**
	 * Called when a user chooses a specific value in the <code>JComboBox</code>
	 * that this class listens to
	 *
	 * @param ae  The generated <code>ActionEvent</code>
	 */
	public void actionPerformed(ActionEvent ae) {
		combo = (JComboBox) ae.getSource();
		String line = (String) combo.getSelectedItem();
		if (line.equals(word)) {
			new FontChooser(this, title).setVisible(true);
			updatePreview();
		}
	}


	/**
	 * Allows setting the <code>JComboBox</code> value when retrieved from the
	 * chooser.
	 *
	 * @param strings  The value list retreived from the chooser
	 */
	public void setValues(String[] strings) {
		String values = "";
		for (int i = 0; i < strings.length; i++) {
			values += "'" + strings[i] + "'" + (i == strings.length - 1 ? "" : ",");
		}
		combo.addItem(values);
		combo.setSelectedItem(values);
	}
}

