package net.java.dev.csseditor.listeners;

import java.awt.event.ActionEvent;

import javax.swing.JComboBox;

import net.java.dev.csseditor.choosers.PercentChooser;
import net.java.dev.csseditor.tabs.AbstractTabPanel;

/**
 * A <code>Listener</code> that allows showing a specific chooser when the user
 * is choosing a specific word in a <code>Combobox</code>
 *
 * @author   <a href="mailto:uzi@landsmanns.com">Uzi Landsmann</a>
 * @see      net.java.dev.csseditor.choosers.PercentChooser
 */
public class PercentListener extends AbstractListener {

	/**
	 * Constructor for the PercentListener object
	 *
	 * @param owner  the panel which owns this listener
	 * @param title  the title to use on the chooser
	 * @param word   the word to look for when an action was performed
	 */
	public PercentListener(AbstractTabPanel owner, String title, String word) {
		super(owner, title, word);
	}


	/**
	 * Called upon an action, checks if the specified word was chosen and call the
	 * chooser if so
	 *
	 * @param ae  the action event
	 */
	public void actionPerformed(ActionEvent ae) {
		combo = (JComboBox) ae.getSource();
		String line = (String) combo.getSelectedItem();
		if (line.equals(word)) {
			new PercentChooser(this, title).setVisible(true);
			updatePreview();
		}
	}
}

