package net.java.dev.csseditor.listeners;

import java.awt.event.ActionEvent;

import javax.swing.JComboBox;

import net.java.dev.csseditor.choosers.StringChooser;
import net.java.dev.csseditor.tabs.AbstractTabPanel;

/**
 * A <code>Listener</code> that allows showing a specific chooser when the user
 * is choosing a specific word in a <code>Combobox</code>
 *
 * @author   <a href="mailto:uzi@landsmanns.com">Uzi Landsmann</a>
 * @see      net.java.dev.csseditor.choosers.StringChooser
 */
public class StringListener extends AbstractListener {

	private String[] arguments;
	private String wrapper;


	/**
	 * Constructor for the SizeListener object
	 *
	 * @param owner      the panel which owns this listener
	 * @param title      the title to use on the chooser
	 * @param word       the word to look for when an action was performed
	 * @param arguments  arguments to send to the chooser
	 * @param wrapper    wrapper to use for the arguments or an empty string if
	 *      none is needed
	 */
	public StringListener(AbstractTabPanel owner, String title, String word, String[] arguments, String wrapper) {
		super(owner, title, word);
		this.arguments = arguments;
		this.wrapper = wrapper;
	}


	/**
	 * Called upon an action, checks if the specified word was chosen and call the
	 * chooser if so
	 *
	 * @param ae  the action event
	 */
	public void actionPerformed(ActionEvent ae) {
		combo = (JComboBox) ae.getSource();
		String line = (String) combo.getSelectedItem();
		if (line.equals(word)) {
			new StringChooser(this, title, arguments).setVisible(true);
			updatePreview();
		}
	}


	/**
	 * Allows setting the <code>ComboBox</code> value when retrieved from the
	 * chooser
	 *
	 * @param strings  The value retreived from the chooser
	 */
	public void setValues(String[] strings) {

		String values = "";

		values += (wrapper.equals("") ? "" : wrapper + "(");
		for (int i = 0; i < strings.length; i++) {
			values += strings[i] + " ";
		}
		values += (wrapper.equals("") ? "" : ")");

		combo.addItem(values);
		combo.setSelectedItem(values);
	}
}

