package net.java.dev.csseditor.tabs;

import java.awt.Color;
import java.awt.Dimension;
import java.awt.event.ActionEvent;
import java.awt.event.ActionListener;
import java.awt.FlowLayout;
import java.awt.Font;

import java.util.EventListener;
import java.util.Iterator;
import java.util.Map;
import java.util.Properties;
import java.util.Set;
import java.util.TreeMap;

import javax.swing.event.ChangeEvent;
import javax.swing.event.ChangeListener;
import javax.swing.JComboBox;
import javax.swing.JComponent;
import javax.swing.JLabel;
import javax.swing.JPanel;
import javax.swing.JEditorPane;
import javax.swing.JTextPane;

import net.java.dev.csseditor.CssEditor;
import net.java.dev.csseditor.EditorFrame;
import net.java.dev.csseditor.StyledComboBox;

/**
 * A general tab panel
 *
 * @author   <a href="mailto:uzi@landsmanns.com">Uzi Landsmann</a>
 */
public abstract class AbstractTabPanel extends JPanel {

	/** List with color names */
	public final static String[] colorList = {"", "color...", "Transparent", "AliceBlue", "AntiqueWhite", "Aqua", "Aquamarine", "Azure", "Beige", "Bisque", "Black", "BlanchedAlmond", "Blue", "BlueViolet", "Brown", "BurlyWood", "CadetBlue", "Chartreuse", "Chocolate", "Coral", "CornflowerBlue", "Cornsilk", "Crimson", "Cyan", "DarkBlue", "DarkCyan", "DarkGoldenRod", "DarkGray", "DarkGreen", "DarkKhaki", "DarkMagenta", "DarkOliveGreen", "Darkorange", "DarkOrchid", "DarkRed", "DarkSalmon", "DarkSeaGreen", "DarkSlateBlue", "DarkSlateGray", "DarkTurquoise", "DarkViolet", "DeepPink", "DeepSkyBlue", "DimGray", "DodgerBlue", "Feldspar", "FireBrick", "FloralWhite", "ForestGreen", "Fuchsia", "Gainsboro", "GhostWhite", "Gold", "GoldenRod", "Gray", "Green", "GreenYellow", "HoneyDew", "HotPink", "IndianRed", "Indigo", "Ivory", "Khaki", "Lavender", "LavenderBlush", "LawnGreen", "LemonChiffon", "LightBlue", "LightCoral", "LightCyan", "LightGoldenRodYellow", "LightGrey", "LightGreen", "LightPink", "LightSalmon", "LightSeaGreen", "LightSkyBlue", "LightSlateBlue", "LightSlateGray", "LightSteelBlue", "LightYellow", "Lime", "LimeGreen", "Linen", "Magenta", "Maroon", "MediumAquaMarine", "MediumBlue", "MediumOrchid", "MediumPurple", "MediumSeaGreen", "MediumSlateBlue", "MediumSpringGreen", "MediumTurquoise", "MediumVioletRed", "MidnightBlue", "MintCream", "MistyRose", "Moccasin", "NavajoWhite", "Navy", "OldLace", "Olive", "OliveDrab", "Orange", "OrangeRed", "Orchid", "PaleGoldenRod", "PaleGreen", "PaleTurquoise", "PaleVioletRed", "PapayaWhip", "PeachPuff", "Peru", "Pink", "Plum", "PowderBlue", "Purple", "Red", "RosyBrown", "RoyalBlue", "SaddleBrown", "Salmon", "SandyBrown", "SeaGreen", "SeaShell", "Sienna", "Silver", "SkyBlue", "SlateBlue", "SlateGray", "Snow", "SpringGreen", "SteelBlue", "Tan", "Teal", "Thistle", "Tomato", "Turquoise", "Violet", "VioletRed", "Wheat", "White", "WhiteSmoke", "Yellow", "YellowGreen"};
	/** JComboBox max width */
	public final static int MAX_COMBO_WIDTH = 125;
	/** JComboBox max height */
	public final static int MAX_COMBO_HEIGHT = 20;
	/** JTextField max width */
	public final static int MAX_FIELD_WIDTH = 11;
	/** A wide JTextField */
	public final static int LARGE_FIELD = 25;
	/** JLabel max width */
	public final static int MAX_LABEL_WIDTH = 120;
	/** JLabel max height */
	public final static int MAX_LABEL_HEIGHT = 20;

	//Background
	
	/** Description of the Field */
	public final static String TT_BACKGROUND = "A shorthand property for setting all background properties in one declaration";
	/** Description of the Field */
	public final static String TT_BACKGROUND_ATTACHMENT = "Sets whether a background image is fixed or scrolls with the rest of the page";
	/** Description of the Field */
	public final static String TT_BACKGROUND_COLOR = "Sets the background color of an element";
	/** Description of the Field */
	public final static String TT_BACKGROUND_IMAGE = "Sets an image as the background";
	/** Description of the Field */
	public final static String TT_BACKGROUND_POSITION = "Sets the starting position of a background image";
	/** Description of the Field */
	public final static String TT_BACKGROUND_REPEAT = "Sets if/how a background image will be repeated";

	//Border

	/** Description of the Field */
	public final static String TT_BORDER = "A shorthand property for setting all of the properties for the four borders in one declaration";
	/** Description of the Field */
	public final static String TT_BORDER_BOTTOM = "A shorthand property for setting all of the properties for the bottom border in one declaration";
	/** Description of the Field */
	public final static String TT_BORDER_BOTTOM_COLOR = "Sets the color of the bottom border";
	/** Description of the Field */
	public final static String TT_BORDER_BOTTOM_STYLE = "Sets the style of the bottom border";
	/** Description of the Field */
	public final static String TT_BORDER_BOTTOM_WIDTH = "Sets the width of the bottom border";
	/** Description of the Field */
	public final static String TT_BORDER_COLOR = "Sets the color of the four borders, can have from one to four colors";
	/** Description of the Field */
	public final static String TT_BORDER_LEFT = "A shorthand property for setting all of the properties for the left border in one declaration";
	/** Description of the Field */
	public final static String TT_BORDER_LEFT_COLOR = "Sets the color of the left border";
	/** Description of the Field */
	public final static String TT_BORDER_LEFT_STYLE = "Sets the style of the left border";
	/** Description of the Field */
	public final static String TT_BORDER_LEFT_WIDTH = "Sets the width of the left border";
	/** Description of the Field */
	public final static String TT_BORDER_RIGHT = "A shorthand property for setting all of the properties for the right border in one declaration";
	/** Description of the Field */
	public final static String TT_BORDER_RIGHT_COLOR = "Sets the color of the right border";
	/** Description of the Field */
	public final static String TT_BORDER_RIGHT_STYLE = "Sets the style of the right border";
	/** Description of the Field */
	public final static String TT_BORDER_RIGHT_WIDTH = "Sets the width of the right border";
	/** Description of the Field */
	public final static String TT_BORDER_STYLE = "Sets the style of the four borders, can have from one to four styles";
	/** Description of the Field */
	public final static String TT_BORDER_TOP = "A shorthand property for setting all of the properties for the top border in one declaration";
	/** Description of the Field */
	public final static String TT_BORDER_TOP_COLOR = "Sets the color of the top border";
	/** Description of the Field */
	public final static String TT_BORDER_TOP_STYLE = "Sets the style of the top border";
	/** Description of the Field */
	public final static String TT_BORDER_TOP_WIDTH = "Sets the width of the top border";
	/** Description of the Field */
	public final static String TT_BORDER_WIDTH = "A shorthand property for setting the width of the four borders in one declaration, can have from one to four values";

	//Classification

	/** Description of the Field */
	public final static String TT_CLEAR = "Sets the sides of an element where other floating elements are not allowed";
	/** Description of the Field */
	public final static String TT_CURSOR = "Specifies the type of cursor to be displayed";
	/** Description of the Field */
	public final static String TT_DISPLAY = "Sets how/if an element is displayed";
	/** Description of the Field */
	public final static String TT_FLOAT = "Sets where an image or a text will appear in another element";
	/** Description of the Field */
	public final static String TT_POSITION = "Places an element in a static, relative, absolute or fixed position";
	/** Description of the Field */
	public final static String TT_VISIBILITY = "Sets if an element should be visible or invisible";

	//Dimension

	/** Description of the Field */
	public final static String TT_HEIGHT = "Sets the height of an element";
	/** Description of the Field */
	public final static String TT_LINE_HEIGHT = "Sets the distance between lines";
	/** Description of the Field */
	public final static String TT_MAX_HEIGHT = "Sets the maximum height of an element";
	/** Description of the Field */
	public final static String TT_MAX_WIDTH = "Sets the maximum width of an element";
	/** Description of the Field */
	public final static String TT_MIN_HEIGHT = "Sets the minimum height of an element";
	/** Description of the Field */
	public final static String TT_MIN_WIDTH = "Sets the minimum width of an element";
	/** Description of the Field */
	public final static String TT_WIDTH = "Sets the width of an element";

	//Font

	/** Description of the Field */
	public final static String TT_FONT = "A shorthand property for setting all of the properties for a font in one declaration";
	/** Description of the Field */
	public final static String TT_FONT_FAMILY = "A prioritized list of font family names and/or generic family names for an element";
	/** Description of the Field */
	public final static String TT_FONT_SIZE = "Sets the size of a font";
	/** Description of the Field */
	public final static String TT_FONT_SIZE_ADJUST = "Specifies an aspect value for an element that will preserve the x_height of the first_choice font";
	/** Description of the Field */
	public final static String TT_FONT_STRETCH = "Condenses or expands the current font-family";
	/** Description of the Field */
	public final static String TT_FONT_STYLE = "Sets the style of the font";
	/** Description of the Field */
	public final static String TT_FONT_VARIANT = "Displays text in a small-caps font or a normal font";
	/** Description of the Field */
	public final static String TT_FONT_WEIGHT = "Sets the weight of a font";

	//Content

	/** Description of the Field */
	public final static String TT_CONTENT = "Generates content in a document. Used with the :before and :after pseudo_elements";
	/** Description of the Field */
	public final static String TT_COUNTER_INCREMENT = "Sets how much the counter increments on each occurrence of a selector";
	/** Description of the Field */
	public final static String TT_COUNTER_RESET = "Sets the value the counter is set to on each occurrence of a selector";
	/** Description of the Field */
	public final static String TT_QUOTES = "Sets the type of quotation marks";

	//List

	/** Description of the Field */
	public final static String TT_LIST_STYLE = "A shorthand property for setting all of the properties for a list in one declaration";
	/** Description of the Field */
	public final static String TT_LIST_STYLE_IMAGE = "Sets an image as the list-item marker";
	/** Description of the Field */
	public final static String TT_LIST_STYLE_POSITION = "Sets where the list-item marker is placed in the list";
	/** Description of the Field */
	public final static String TT_LIST_STYLE_TYPE = "Sets the type of the list-item marker";
	/** Description of the Field */
	public final static String TT_MARKER_OFFSET = "";

	//Margin

	/** Description of the Field */
	public final static String TT_MARGIN = "A shorthand property for setting the margin properties in one declaration";
	/** Description of the Field */
	public final static String TT_MARGIN_BOTTOM = "Sets the bottom margin of an element";
	/** Description of the Field */
	public final static String TT_MARGIN_LEFT = "Sets the left margin of an element";
	/** Description of the Field */
	public final static String TT_MARGIN_RIGHT = "Sets the right margin of an element";
	/** Description of the Field */
	public final static String TT_MARGIN_TOP = "Sets the top margin of an element";

	//Outlines

	/** Description of the Field */
	public final static String TT_OUTLINE = "A shorthand property for setting all the outline properties in one declaration";
	/** Description of the Field */
	public final static String TT_OUTLINE_COLOR = "Sets the color of the outline around an element";
	/** Description of the Field */
	public final static String TT_OUTLINE_STYLE = "Sets the style of the outline around an element";
	/** Description of the Field */
	public final static String TT_OUTLINE_WIDTH = "Sets the width of the outline around an element";

	//Padding

	/** Description of the Field */
	public final static String TT_PADDING = "A shorthand property for setting all of the padding properties in one declaration";
	/** Description of the Field */
	public final static String TT_PADDING_BOTTOM = "Sets the bottom padding of an element";
	/** Description of the Field */
	public final static String TT_PADDING_LEFT = "Sets the left padding of an element";
	/** Description of the Field */
	public final static String TT_PADDING_RIGHT = "Sets the right padding of an element";
	/** Description of the Field */
	public final static String TT_PADDING_TOP = "Sets the top padding of an element";

	//Positioning

	/** Description of the Field */
	public final static String TT_BOTTOM = "Sets how far the bottom edge of an element is above/below the bottom edge of the parent element";
	/** Description of the Field */
	public final static String TT_CLIP = "Sets the shape of an element. The element is clipped into this shape, and displayed";
	/** Description of the Field */
	public final static String TT_LEFT = "Sets how far the left edge of an element is to the right/left of the left edge of the parent element";
	/** Description of the Field */
	public final static String TT_OVERFLOW = "Sets what happens if the content of an element overflow its area";
	/** Description of the Field */
	public final static String TT_RIGHT = "Sets how far the right edge of an element is to the left/right of the right edge of the parent element";
	/** Description of the Field */
	public final static String TT_TOP = "Sets how far the top edge of an element is above/below the top edge of the parent element";
	/** Description of the Field */
	public final static String TT_VERTICAL_ALIGN = "Sets the vertical alignment of an element";
	/** Description of the Field */
	public final static String TT_Z_INDEX = "Sets the stack order of an element";

	//Table

	/** Description of the Field */
	public final static String TT_BORDER_COLLAPSE = "Sets the border model of a table";
	/** Description of the Field */
	public final static String TT_BORDER_SPACING = "Sets the distance between the borders of adjacent cells (only for the \"separated borders\" model)";
	/** Description of the Field */
	public final static String TT_CAPTION_SIDE = "Sets the position of the caption according to the table";
	/** Description of the Field */
	public final static String TT_EMPTY_CELLS = "Sets whether cells with no visible content should have borders or not (only for the \"separated borders\" model)";
	/** Description of the Field */
	public final static String TT_TABLE_LAYOUT = "Sets the algorithm used to lay out the table";

	//Text

	/** Description of the Field */
	public final static String TT_COLOR = "Sets the color of a text";
	/** Description of the Field */
	public final static String TT_DIRECTION = "Sets the text direction";
	/** Description of the Field */
	public final static String TT_LETTER_SPACING = "Increase or decrease the space between characters";
	/** Description of the Field */
	public final static String TT_TEXT_ALIGN = "Aligns the text in an element";
	/** Description of the Field */
	public final static String TT_TEXT_DECORATION = "Adds decoration to text";
	/** Description of the Field */
	public final static String TT_TEXT_INDENT = "Indents the first line of text in an element";
	/** Description of the Field */
	public final static String TT_TEXT_SHADOW = "";
	/** Description of the Field */
	public final static String TT_TEXT_TRANSFORM = "Controls the letters in an element";
	/** Description of the Field */
	public final static String TT_UNICODE_BIDI = "";
	/** Description of the Field */
	public final static String TT_WHITE_SPACE = "Sets how white space inside an element is handled";
	/** Description of the Field */
	public final static String TT_WORD_SPACING = "Increase or decrease the space between words";

	/** The css editor object */
	protected EditorFrame editor;
	/** A listener to updates made in tab panels */
	protected UpdateListener updateListener = new UpdateListener();
	/** The tab panel list of fields containing css comboboxes */
	protected Map fields = new TreeMap();
	/*  The links to the description of the field */
	protected Map links = new TreeMap();
	/** Description of the Field */
	protected Properties tooltips = new Properties();


	/**
	 * Constructor for the AbstractTabPanel object
	 *
	 * @param editor  Description of the Parameter
	 */
	public AbstractTabPanel(EditorFrame editor) {
		this.editor = editor;
	}


	/**
	 * Creates a <code>JComboBox</code> given a list of values using a <code>StyledComboBox</code>
	 * props
	 *
	 * @param list     the list of values to include in the <code>JComboBox</code>
	 * @param tooltip  Description of the Parameter
	 * @return         an instance of <code>JComboBox</code>
	 */
	protected JComboBox createCombo(String[] list, String tooltip) {
		JComboBox combo = new StyledComboBox(list, tooltip);
		combo.setPreferredSize(new Dimension(MAX_COMBO_WIDTH, MAX_COMBO_HEIGHT));

		return combo;
	}


	/**
	 * Add all fields to a given <code>JPanel</code>
	 *
	 * @param panel  the <code>JPanel</code> to add the fields to
	 */
	protected void addComponents(JPanel panel) {
		Set names = fields.keySet();
		Iterator iter = names.iterator();
		while (iter.hasNext()) {
			String name = (String) iter.next();
			JComponent component = (JComponent) fields.get(name);
			String link = (String)links.get(name);
			if (link == null){
				link = "";	
			}
			addPanel(panel, name + ":", component, updateListener, link);
		}
	}


	/**
	 * Enable or disable all components in the panel
	 *
	 * @param boo  true if components should be enables, or false otherwise
	 */
	public void enableComponents(boolean boo) {
		Set names = fields.keySet();
		Iterator iter = names.iterator();
		while (iter.hasNext()) {
			String name = (String) iter.next();
			JComponent component = (JComponent) fields.get(name);
			component.setEnabled(boo);
		}
	}


	/** clears all the values in the <code>JComboBox</code>es */
	public void clearFields() {
		Set names = fields.keySet();
		Iterator iter = names.iterator();
		while (iter.hasNext()) {
			String name = (String) iter.next();
			JComponent component = (JComponent) fields.get(name);
			if (component instanceof JComboBox) {
				((JComboBox) component).setSelectedItem("");
			}
		}
	}


	/**
	 * Adds all values in the <code>JComboBox</code>es in a <code>Map</code>
	 *
	 * @param props  the <code>Map</code> to add the values to
	 */
	public void getFields(Map props) {
		Set names = fields.keySet();
		Iterator iter = names.iterator();
		while (iter.hasNext()) {
			String name = (String) iter.next();
			JComponent component = (JComponent) fields.get(name);
			String value = null;
			if (component instanceof JComboBox) {
				value = (String) ((JComboBox) component).getSelectedItem();
			}

			if (value != null && !value.endsWith("...")) {
				if (!value.equals("")) {
					props.put(name, value);
				} else {
					props.remove(name);
				}
			}
		}
	}


	/**
	 * Adds a <code>JLabel</code> containing a given text to a given <code>JPanel</code>
	 *
	 * @param addTo  the <code>JPanel</code> to add to
	 * @param name   the text to add
	 */
	protected static void addPanel(JPanel addTo, String name, String link) {
		addPanel(addTo, name, new JComponent[]{}, null, link);
	}


	/**
	 * Adds a <code>JLabel</code> containing a given text and a given <code>JComponent</code>
	 * to a given <code>JPanel</code>
	 *
	 * @param addTo     the <code>JPanel</code> to add to
	 * @param name      the text to add
	 * @param comp      the <code>JCompoent</code> to add
	 * @param listener  an <code>EventListener</code> to add to the <code>JComponent</code>
	 */
	protected static void addPanel(JPanel addTo, String name, JComponent comp,
			EventListener listener, String link) {
		addPanel(addTo, name, new JComponent[]{comp}, listener, link);
	}


	/**
	 * Adds a <code>JLabel</code> containing a given text and a given <code>JComponent</code>
	 * array to a given <code>JPanel</code>
	 *
	 * @param addTo       the <code>JPanel</code> to add to
	 * @param name        the text to add
	 * @param components  the <code>JComponent</code> array to add
	 * @param listener    an <code>EventListener</code> to add to the <code>JComponent</code>
	 *      s
	 */
	protected static void addPanel(JPanel addTo, String name, JComponent[] components,
			EventListener listener, String link) {
		JPanel panel = new JPanel();
		panel.setLayout(new FlowLayout(FlowLayout.LEFT));
		panel.setBackground(Color.white);
		
		JEditorPane editPanel = new JEditorPane();
		editPanel.setEditable(false);
		editPanel.setContentType("text/html");
		editPanel.setPreferredSize(new Dimension(MAX_LABEL_WIDTH, MAX_LABEL_HEIGHT));
		
		editPanel.setText("<html><a style='font-size: 10' href='" + link + "'>" + name + "</a></html>");
		
		LabelLinkListener linkListener = new LabelLinkListener();
		editPanel.addHyperlinkListener(linkListener);		
		
		panel.add(editPanel);
		
		for (int i = 0; i < components.length; i++) {
			panel.add(components[i]);
			if (components[i] instanceof JComboBox) {
				((JComboBox) components[i]).addActionListener((ActionListener) listener);
			}
		}
		
		addTo.add(panel);
	}

	/**
	 * Sets the props attribute of the AbstractTabPanel object
	 *
	 * @param props  The new props value
	 */
	public void setProps(Map props) {
		Set keys = props.keySet();
		Iterator iter = keys.iterator();
		while (iter.hasNext()) {
			String key = ((String) iter.next()).trim().toLowerCase();
			if (fields.containsKey(key)) {
				JComboBox combo = (JComboBox) fields.get(key);
				String obj = ((String) props.get(key)).trim().toLowerCase();

				if (!isInComboBox(obj, combo)) {
					combo.addItem(obj);
				}

				combo.setSelectedItem(obj);
				//props.remove(key);
			}
		}
	}


	/**
	 * Gets the inComboBox attribute of the AbstractTabPanel object
	 *
	 * @param item   Description of the Parameter
	 * @param combo  Description of the Parameter
	 * @return       The inComboBox value
	 */
	private boolean isInComboBox(String item, JComboBox combo) {
		for (int i = 0; i < combo.getItemCount(); i++) {
			String currentItem = (String) combo.getItemAt(i);
			if (currentItem.trim().toLowerCase().equals(item.trim().toLowerCase())) {
				return true;
			}
		}
		return false;
	}


	/**
	 * Gets the itemIndexInCombo attribute of the AbstractTabPanel object
	 *
	 * @param item   Description of the Parameter
	 * @param combo  Description of the Parameter
	 * @return       The itemIndexInCombo value
	 */
	private int getItemIndexInCombo(String item, JComboBox combo) {
		for (int i = 0; i < combo.getItemCount(); i++) {
			String currentItem = (String) combo.getItemAt(i);
			if (currentItem.trim().toLowerCase().equals(item.trim().toLowerCase())) {
				return i;
			}
		}
		return -1;
	}


	/**
	 * A <code>Listener</code> to updates made in the <code>JPanels</code>
	 * components which requires updating the preview panel
	 *
	 * @author   <a href="mailto:uzi@landsmanns.com">uzi@landsmanns.com</a>
	 */
	private class UpdateListener implements ActionListener, ChangeListener {
		/**
		 * Listens to Action events
		 *
		 * @param ae  The action event
		 */
		public void actionPerformed(ActionEvent ae) {
			updatePreview();
		}


		/**
		 * Listens to state change events
		 *
		 * @param ce  the state change event
		 */
		public void stateChanged(ChangeEvent ce) {
			updatePreview();
		}


		/** Allows calling the editor's updateExample method */
		public void updatePreview() {
			CssEditor.getEditor().updatePreview();
		}
	}
}


