package net.java.dev.csseditor.tabs;

import java.awt.BorderLayout;
import java.awt.Color;

import javax.swing.BorderFactory;
import javax.swing.BoxLayout;
import javax.swing.JComboBox;
import javax.swing.JPanel;

import net.java.dev.csseditor.EditorFrame;
import net.java.dev.csseditor.listeners.ColorListener;
import net.java.dev.csseditor.listeners.DoublePercentListener;
import net.java.dev.csseditor.listeners.DoubleSizeUnitListener;
import net.java.dev.csseditor.listeners.FileListener;

/**
 * Diplays a panel that allows users to manipulate css background properties
 *
 * @author   <a href="mailto:uzi@landsmanns.com">Uzi Landsmann</a>
 */
public class Background extends AbstractTabPanel {

	private JPanel top = new JPanel();
	private JPanel center = new JPanel();

	private JComboBox colorCombo = createCombo(colorList, TT_BACKGROUND_COLOR);

	private String[] imageFileList = {"", "file..."};
	private JComboBox imageFileCombo = createCombo(imageFileList, TT_BACKGROUND_IMAGE);

	private String[] attachmentList = {"", "scroll", "fixed"};
	private JComboBox attachmentCombo = createCombo(attachmentList, TT_BACKGROUND_ATTACHMENT);

	private String[] repeatList = {"", "repeat", "repeat-x", "repeat-y", "no-repeat"};
	private JComboBox repeatCombo = createCombo(repeatList, TT_BACKGROUND_REPEAT);

	private String[] positionList = {"", "percent...", "position...", "top top", "top center", "top right", "center top", "center center", "center right", "bottom top", "bottom center", "bottom right"};
	private JComboBox positionCombo = createCombo(positionList, TT_BACKGROUND_POSITION);


	/**
	 * Constructor for the CssBorder object
	 *
	 * @param editor  Description of the Parameter
	 */
	public Background(EditorFrame editor) {
		super(editor);

		setLayout(new BorderLayout());
		top.setLayout(new BoxLayout(top, BoxLayout.Y_AXIS));
		top.setBorder(BorderFactory.createTitledBorder("Background"));

		setBackground(Color.white);
		top.setBackground(Color.white);
		center.setBackground(Color.white);

		fields.put("background-color", colorCombo);
		fields.put("background-image", imageFileCombo);
		fields.put("background-repeat", repeatCombo);
		fields.put("background-attachment", attachmentCombo);
		fields.put("background-position", positionCombo);
		
		links.put("background-color", "http://www.w3schools.com/css/pr_background-color.asp");
		links.put("background-image", "http://www.w3schools.com/css/pr_background-image.asp");
		links.put("background-repeat", "http://www.w3schools.com/css/pr_background-repeat.asp");
		links.put("background-attachment", "http://www.w3schools.com/css/pr_background-attachment.asp");
		links.put("background-position", "http://www.w3schools.com/css/pr_background-position.asp");

		colorCombo.addActionListener(new ColorListener(this, "Choose color", "color..."));
		imageFileCombo.addActionListener(new FileListener(this, "Choose file", "file..."));
		positionCombo.addActionListener(new DoubleSizeUnitListener(this, "Choose position", "position..."));
		positionCombo.addActionListener(new DoublePercentListener(this, "Choose position", "percent..."));

		addComponents(top);
		add(top, BorderLayout.NORTH);
		add(center, BorderLayout.CENTER);
	}
}


