package net.java.dev.csseditor.tabs;

import java.awt.BorderLayout;
import java.awt.Color;

import javax.swing.BorderFactory;
import javax.swing.BoxLayout;
import javax.swing.JComboBox;
import javax.swing.JPanel;

import net.java.dev.csseditor.EditorFrame;
import net.java.dev.csseditor.listeners.ColorListener;
import net.java.dev.csseditor.listeners.SizeUnitListener;

/**
 * Diplays a panel that allows users to manipulate css border properties
 *
 * @author   <a href="mailto:uzi@landsmanns.com">Uzi Landsmann</a>
 */
public class Border extends AbstractTabPanel {

	private JPanel top = new JPanel();
	private JPanel center = new JPanel();
	private JPanel borderPanel = this;

	private String[] suffices = {"", "-top", "-left", "-bottom", "-right"};
	private JComboBox[] baseCombos = new JComboBox[suffices.length];

	// border width
	private String[] widthList = {"", "size...", "thin", "medium", "thick"};
	private JComboBox[] widthCombos = new JComboBox[suffices.length];

	//border style
	private String[] styleList = {"", "none", "hidden", "dotted", "dashed", "solid", "double", "groove", "ridge", "inset", "outset"};
	private JComboBox[] styleCombos = new JComboBox[suffices.length];

	//border color
	private JComboBox[] colorCombos = new JComboBox[suffices.length];


	/**
	 * Constructor for the CssBorder object
	 *
	 * @param editor  Description of the Parameter
	 */
	public Border(EditorFrame editor) {
		super(editor);

		setLayout(new BorderLayout());
		top.setLayout(new BoxLayout(top, BoxLayout.Y_AXIS));

		setBackground(Color.white);
		top.setBackground(Color.white);
		center.setBackground(Color.white);

		for (int i = 0; i < widthCombos.length; i++) {
			JPanel panel = new JPanel();
			panel.setLayout(new BoxLayout(panel, BoxLayout.Y_AXIS));
			panel.setBackground(Color.white);
			panel.setBorder(BorderFactory.createTitledBorder("Border" + suffices[i]));

			String baseName = "border" + suffices[i];
			String widthName = baseName + "-width";
			String styleName = baseName + "-style";
			String colorName = baseName + "-color";
			
			String baseUrl = "http://www.w3schools.com/css/pr_" + baseName + ".asp";
			String widthUrl = "http://www.w3schools.com/css/pr_" + baseName + (suffices[i] == "" ? "-" : "_") + "width.asp";
			String styleUrl = "http://www.w3schools.com/css/pr_" + baseName + (suffices[i] == "" ? "-" : "_") + "style.asp";
			String colorUrl = "http://www.w3schools.com/css/pr_" + baseName + (suffices[i] == "" ? "-" : "_") + "color.asp";

			String ttBase = "";

			String ttWidth = "";

			String ttStyle = "";

			String ttColor = "";
			switch (i) {
				case 0:
					ttBase = TT_BORDER;
					ttWidth = TT_BORDER_WIDTH;
					ttColor = TT_BORDER_COLOR;
					ttStyle = TT_BORDER_STYLE;
					break;
				case 1:
					ttBase = TT_BORDER_TOP;
					ttWidth = TT_BORDER_TOP_WIDTH;
					ttColor = TT_BORDER_TOP_COLOR;
					ttStyle = TT_BORDER_TOP_STYLE;
					break;
				case 2:
					ttBase = TT_BORDER_LEFT;
					ttWidth = TT_BORDER_LEFT_WIDTH;
					ttColor = TT_BORDER_LEFT_COLOR;
					ttStyle = TT_BORDER_LEFT_STYLE;
					break;
				case 3:
					ttBase = TT_BORDER_BOTTOM;
					ttWidth = TT_BORDER_BOTTOM_WIDTH;
					ttColor = TT_BORDER_BOTTOM_COLOR;
					ttStyle = TT_BORDER_BOTTOM_STYLE;
					break;
				case 4:
					ttBase = TT_BORDER_RIGHT;
					ttWidth = TT_BORDER_RIGHT_WIDTH;
					ttColor = TT_BORDER_RIGHT_COLOR;
					ttStyle = TT_BORDER_RIGHT_STYLE;
					break;
			}

			baseCombos[i] = createCombo(new String[]{""}, ttBase);
			widthCombos[i] = createCombo(widthList, ttWidth);
			styleCombos[i] = createCombo(styleList, ttStyle);
			colorCombos[i] = createCombo(colorList, ttColor);

			fields.put(baseName, baseCombos[i]);
			fields.put(widthName, widthCombos[i]);
			fields.put(styleName, styleCombos[i]);
			fields.put(colorName, colorCombos[i]);

			links.put(baseName, baseUrl);
			links.put(widthName, widthUrl);
			links.put(styleName, styleUrl);
			links.put(colorName, colorUrl);

			widthCombos[i].addActionListener(new SizeUnitListener(this, "Choose width", "size..."));
			colorCombos[i].addActionListener(new ColorListener(this, "Choose color", "color..."));

			String link = (String)links.get(baseName);
			if (link == null){
				link = "";	
			}
			addPanel(panel, baseName + ":", baseCombos[i], updateListener, link);
			
			link = (String)links.get(widthName);
			if (link == null){
				link = "";	
			}
			addPanel(panel, widthName + ":", widthCombos[i], updateListener, link);
			
			link = (String)links.get(styleName);
			if (link == null){
				link = "";	
			}
			addPanel(panel, styleName + ":", styleCombos[i], updateListener, link);
			
			link = (String)links.get(colorName);
			if (link == null){
				link = "";	
			}
			addPanel(panel, colorName + ":", colorCombos[i], updateListener, link);
			top.add(panel);
		}
		add(top, BorderLayout.NORTH);
		add(center, BorderLayout.CENTER);
	}
}


