package net.java.dev.csseditor.tabs;

import java.awt.BorderLayout;
import java.awt.Color;

import javax.swing.BorderFactory;
import javax.swing.BoxLayout;
import javax.swing.JComboBox;
import javax.swing.JPanel;

import net.java.dev.csseditor.EditorFrame;
import net.java.dev.csseditor.listeners.FileListener;

/**
 * Diplays a panel that allows users to manipulate css background properties
 *
 * @author   <a href="mailto:uzi@landsmanns.com">Uzi Landsmann</a>
 */
public class Classification extends AbstractTabPanel {

	private JPanel top = new JPanel();
	private JPanel center = new JPanel();

	private String[] clearList = {"", "left", "right", "both", "none"};
	private JComboBox clearCombo = createCombo(clearList, TT_CLEAR);

	private String[] cursorList = {"", "file...", "auto", "crosshair", "default", "pointer", "move", "e-resize", "ne-resize", "nw-resize", "n-resize", "se-resize", "sw-resize", "s-resize", "w-resize", "text", "wait", "help"};
	private JComboBox cursorCombo = createCombo(cursorList, TT_CURSOR);

	private String[] displayList = {"", "none", "inline", "block", "list-item", "run-in", "compact", "marker", "table", "inline-table", "table-row-group", "table-header-group", "table-footer-group", "table-row", "table-column-group", "table-column", "table-cell", "table-caption"};
	private JComboBox displayCombo = createCombo(displayList, TT_DISPLAY);

	private String[] floatList = {"", "none", "left", "right"};
	private JComboBox floatCombo = createCombo(floatList, TT_FLOAT);

	private String[] positionList = {"", "static", "relative", "absolute", "fixed"};
	private JComboBox positionCombo = createCombo(positionList, TT_POSITION);

	private String[] visibilityList = {"", "visible", "hidden", "collapse"};
	private JComboBox visibilityCombo = createCombo(visibilityList, TT_VISIBILITY);


	/**
	 * Constructor for the CssBorder object
	 *
	 * @param editor  Description of the Parameter
	 */
	public Classification(EditorFrame editor) {
		super(editor);

		setLayout(new BorderLayout());
		top.setLayout(new BoxLayout(top, BoxLayout.Y_AXIS));
		top.setBorder(BorderFactory.createTitledBorder("Classification"));

		setBackground(Color.white);
		top.setBackground(Color.white);
		center.setBackground(Color.white);

		fields.put("clear", clearCombo);
		fields.put("cursor", cursorCombo);
		fields.put("display", displayCombo);
		fields.put("float", floatCombo);
		fields.put("position", positionCombo);
		fields.put("visibility", visibilityCombo);

		links.put("clear", "http://www.w3schools.com/css/pr_class_clear.asp");
		links.put("cursor", "http://www.w3schools.com/css/pr_class_cursor.asp");
		links.put("display", "http://www.w3schools.com/css/pr_class_display.asp");
		links.put("float", "http://www.w3schools.com/css/pr_class_float.asp");
		links.put("position", "http://www.w3schools.com/css/pr_class_position.asp");
		links.put("visibility", "http://www.w3schools.com/css/pr_class_visibility.asp");

				
				
		cursorCombo.addActionListener(new FileListener(this, "Choose file", "file..."));

		addComponents(top);
		add(top, BorderLayout.NORTH);
		add(center, BorderLayout.CENTER);
	}
}

