package net.java.dev.csseditor.tabs;

import java.awt.BorderLayout;
import java.awt.Color;

import javax.swing.BorderFactory;
import javax.swing.BoxLayout;
import javax.swing.JComboBox;
import javax.swing.JPanel;

import net.java.dev.csseditor.EditorFrame;
import net.java.dev.csseditor.listeners.StringListener;

/**
 * Diplays a panel that allows users to manipulate css background properties
 *
 * @author   <a href="mailto:uzi@landsmanns.com">Uzi Landsmann</a>
 */
public class Content extends AbstractTabPanel {

	private JPanel top = new JPanel();
	private JPanel center = new JPanel();

	private String[] contentList = {"", "string...", "url...", "counter(name)...", "counter(name, list-style-type)...", "counters(name, string)...", "counters(name, string, list-style-type)...", "attr(X)...", "open-quote", "close-quote", "no-open-quote", "no-close-quote"};
	private JComboBox contentCombo = createCombo(contentList, TT_CONTENT);

	private String[] counterIncrementList = {"", "identifier & number...", "none"};
	private JComboBox counterIncrementCombo = createCombo(counterIncrementList, TT_COUNTER_INCREMENT);

	private String[] counterResetList = {"", "identifier & number...", "none"};
	private JComboBox counterResetCombo = createCombo(counterResetList, TT_COUNTER_RESET);

	private String[] quotesList = {"", "quotes...", "none"};
	private JComboBox quotesCombo = createCombo(quotesList, TT_QUOTES);


	/**
	 * Constructor for the CssBorder object
	 *
	 * @param editor  Description of the Parameter
	 */
	public Content(EditorFrame editor) {
		super(editor);

		setLayout(new BorderLayout());
		top.setLayout(new BoxLayout(top, BoxLayout.Y_AXIS));
		top.setBorder(BorderFactory.createTitledBorder("Content"));

		setBackground(Color.white);
		top.setBackground(Color.white);
		center.setBackground(Color.white);

		fields.put("content", contentCombo);
		fields.put("counter-increment", counterIncrementCombo);
		fields.put("counter-reset", counterResetCombo);
		fields.put("quotes ", quotesCombo);

		links.put("content", "http://www.w3schools.com/css/pr_gen_content.asp");
		links.put("counter-increment", "http://www.w3schools.com/css/pr_gen_counter-increment.asp");
		links.put("counter-reset", "http://www.w3schools.com/css/pr_gen_counter-reset.asp");
		links.put("quotes", "http://www.w3schools.com/css/pr_gen_quotes.asp");

		contentCombo.addActionListener(new StringListener(this, "Choose string", "string...", new String[]{"string"}, ""));
		contentCombo.addActionListener(new StringListener(this, "Choose url", "url...", new String[]{"url"}, "url"));
		contentCombo.addActionListener(new StringListener(this, "Choose counter", "counter(name)...", new String[]{"name"}, "counter"));
		contentCombo.addActionListener(new StringListener(this, "Choose counter", "counter(name, list-style-type)...", new String[]{"name", "list-style-type"}, "counter"));
		contentCombo.addActionListener(new StringListener(this, "Choose counters", "counters(name, string)...", new String[]{"name", "string"}, "counters"));
		contentCombo.addActionListener(new StringListener(this, "Choose counters", "counters(name, string, list-style-type)...", new String[]{"name", "string", "list-style-type"}, "counters"));
		contentCombo.addActionListener(new StringListener(this, "Choose attribute", "attr(X)...", new String[]{"attribute"}, "attr"));

		counterIncrementCombo.addActionListener(new StringListener(this, "Choose counter increment", "identifier & number...", new String[]{"identifier", "number"}, ""));

		counterResetCombo.addActionListener(new StringListener(this, "Choose counter reset", "identifier & number...", new String[]{"identifier", "number"}, ""));

		quotesCombo.addActionListener(new StringListener(this, "Choose quotes strings", "quotes...", new String[]{"quotes"}, ""));

		addComponents(top);
		add(top, BorderLayout.NORTH);
		add(center, BorderLayout.CENTER);
	}
}


