package net.java.dev.csseditor.tabs;

import java.awt.BorderLayout;
import java.awt.Color;

import javax.swing.BorderFactory;
import javax.swing.BoxLayout;
import javax.swing.JComboBox;
import javax.swing.JPanel;

import net.java.dev.csseditor.EditorFrame;
import net.java.dev.csseditor.listeners.PercentListener;
import net.java.dev.csseditor.listeners.SizeListener;
import net.java.dev.csseditor.listeners.SizeUnitListener;

/**
 * Diplays a panel that allows users to manipulate css background properties
 *
 * @author   <a href="mailto:uzi@landsmanns.com">Uzi Landsmann</a>
 */
public class Dimension extends AbstractTabPanel {

	private JPanel top = new JPanel();
	private JPanel center = new JPanel();

	private String[] heightList = {"", "percent...", "length...", "auto"};
	private JComboBox heightCombo = createCombo(heightList, TT_HEIGHT);

	private String[] lineHeightList = {"", "percent...", "length...", "number...", "normal"};
	private JComboBox lineHeightCombo = createCombo(lineHeightList, TT_LINE_HEIGHT);

	private String[] maxHeightList = {"", "percent...", "length...", "none"};
	private JComboBox maxHeightCombo = createCombo(maxHeightList, TT_MAX_HEIGHT);

	private String[] maxWidthList = {"", "percent...", "length...", "none"};
	private JComboBox maxWidthCombo = createCombo(maxWidthList, TT_MAX_WIDTH);

	private String[] minHeightList = {"", "percent...", "length..."};
	private JComboBox minHeightCombo = createCombo(minHeightList, TT_MIN_HEIGHT);

	private String[] minWidthList = {"", "percent...", "length..."};
	private JComboBox minWidthCombo = createCombo(minWidthList, TT_MIN_WIDTH);

	private String[] widthList = {"", "percent...", "length...", "auto"};
	private JComboBox widthCombo = createCombo(widthList, TT_WIDTH);


	/**
	 * Constructor for the CssBorder object
	 *
	 * @param editor  Description of the Parameter
	 */
	public Dimension(EditorFrame editor) {
		super(editor);

		setLayout(new BorderLayout());
		top.setLayout(new BoxLayout(top, BoxLayout.Y_AXIS));
		top.setBorder(BorderFactory.createTitledBorder("Dimension"));

		setBackground(Color.white);
		top.setBackground(Color.white);
		center.setBackground(Color.white);

		fields.put("height", heightCombo);
		fields.put("line-height", lineHeightCombo);
		fields.put("max-height", maxHeightCombo);
		fields.put("max-width", maxWidthCombo);
		fields.put("min-height", minHeightCombo);
		fields.put("min-width", minWidthCombo);
		fields.put("width", widthCombo);

		links.put("height", "http://www.w3schools.com/css/pr_dim_height.asp");
		links.put("line-height", "http://www.w3schools.com/css/pr_dim_line-height.asp");
		links.put("max-height", "http://www.w3schools.com/css/pr_dim_max-height.asp");
		links.put("max-width", "http://www.w3schools.com/css/pr_dim_max-width.asp");
		links.put("min-height", "http://www.w3schools.com/css/pr_dim_min-height.asp");
		links.put("min-width", "http://www.w3schools.com/css/pr_dim_min-width.asp");
		links.put("width", "http://www.w3schools.com/css/pr_dim_width.asp");

		heightCombo.addActionListener(new PercentListener(this, "Choose height", "percent..."));
		heightCombo.addActionListener(new SizeUnitListener(this, "Choose height", "length..."));

		lineHeightCombo.addActionListener(new PercentListener(this, "Choose line height", "percent..."));
		lineHeightCombo.addActionListener(new SizeUnitListener(this, "Choose line height", "length..."));
		lineHeightCombo.addActionListener(new SizeListener(this, "Choose line height", "number..."));

		maxHeightCombo.addActionListener(new PercentListener(this, "Choose max height", "percent..."));
		maxHeightCombo.addActionListener(new SizeUnitListener(this, "Choose max height", "length..."));

		maxWidthCombo.addActionListener(new PercentListener(this, "Choose max width", "percent..."));
		maxWidthCombo.addActionListener(new SizeUnitListener(this, "Choose max width", "length..."));

		minHeightCombo.addActionListener(new PercentListener(this, "Choose min height", "percent..."));
		minHeightCombo.addActionListener(new SizeUnitListener(this, "Choose min height", "length..."));

		minWidthCombo.addActionListener(new PercentListener(this, "Choose min width", "percent..."));
		minWidthCombo.addActionListener(new SizeUnitListener(this, "Choose min width", "length..."));

		widthCombo.addActionListener(new PercentListener(this, "Choose width", "percent..."));
		widthCombo.addActionListener(new SizeUnitListener(this, "Choose width", "length..."));

		addComponents(top);
		add(top, BorderLayout.NORTH);
		add(center, BorderLayout.CENTER);
	}
}


