package net.java.dev.csseditor.tabs;

import java.awt.BorderLayout;
import java.awt.Color;

import javax.swing.BorderFactory;
import javax.swing.BoxLayout;
import javax.swing.JComboBox;
import javax.swing.JPanel;

import net.java.dev.csseditor.EditorFrame;
import net.java.dev.csseditor.listeners.FontListener;
import net.java.dev.csseditor.listeners.PercentListener;
import net.java.dev.csseditor.listeners.SizeListener;
import net.java.dev.csseditor.listeners.SizeUnitListener;

/**
 * Diplays a panel that allows users to manipulate css background properties
 *
 * @author   <a href="mailto:uzi@landsmanns.com">Uzi Landsmann</a>
 */
public class Font extends AbstractTabPanel {

	private JPanel top = new JPanel();
	private JPanel center = new JPanel();

	private String[] fontList = {"", "caption", "icon", "menu", "message-box", "small-caption", "status-bar"};
	private JComboBox fontCombo = createCombo(fontList, TT_FONT);

	private static String[] fontFamilyList = {"", "fonts...", "serif", "sans-serif", "cursive", "fantasy", "monospace", "Aapex", "Aardvark", "'Albertus Extra Bold'", "'Albertus Medium'", "Algerian", "'Antique Olive'", "Arial", "'Arial Black'", "'Arial MT Condensed Light'", "'Arial Narrow'", "'Arial Rounded MT Bold'", "'Bodoni MT Ultra Bold'", "'Book Antiqua'", "'Bookman Old Style'", "Braggadocio", "'Britannic Bold'", "Brooklyn", "'Brush Script MT'", "Carleton", "'Century Gothic'", "'Century Schoolbook'", "Charcoal", "Chicago", "'CG Times'", "'Colonna MT'", "'Comic Sans MS'", "Coronet", "Courier", "'Courier New'", "'Cursive Elegant'", "DawnCastle", "Desdemona", "Donata", "Erie", "Expo", "'Footlight MT Light'", "Fritzquad", "Garamond", "Geneva", "Georgia", "GilbertUltraBold", "'Gill Sans Condensed Bold'", "'GV Terminal'", "Haettenschweiler", "Helvetica", "'Humanst521 Cn BT'", "Impact", "'Kino MT'", "'Klang MT'", "Lansbury", "'Letter Gothic'", "Lincoln", "Marlett", "'Matura MT Script Capitals'", "Merlin", "Micro", "Minion Web", "Modern", "Monaco", "Monotype.com", "Motor", "'MS-DOS CP 437'", "'MS LineDraw'", "'Ner Berolina MT'", "'New York'", "'Old English'", "'Old English Text MT'", "'OzHandicraft BT'", "Palatino", "Playbill", "'Script MT Bold'", "'Small Fonts'", "Sonoma", "'Sonoma Italic'", "'Swiss721 BlkEx BT'", "Terminal", "Times", "'Times New Roman'", "'Trebuchet MS'", "Univers", "'Univers Condensed'", "Verdana", "'Wide Latin'", "'Zap Chance'"};
	private JComboBox fontFamilyCombo = createCombo(fontFamilyList, TT_FONT_FAMILY);

	private String[] fontSizeList = {"", "percent...", "length...", "xx-small", "x-small", "small", "medium", "large", "x-large", "xx-large", "smaller", "larger"};
	private JComboBox fontSizeCombo = createCombo(fontSizeList, TT_FONT_SIZE);

	private String[] fontSizeAdjustList = {"", "number...", "none"};
	private JComboBox fontSizeAdjustCombo = createCombo(fontSizeAdjustList, TT_FONT_SIZE_ADJUST);

	private String[] fontStretchList = {"", "normal", "wider", "narrower", "ultra-condensed", "extra-condensed", "condensed", "semi-condensed", "semi-expanded", "expanded", "extra-expanded", "ultra-expanded"};
	private JComboBox fontStretchCombo = createCombo(fontStretchList, TT_FONT_STRETCH);

	private String[] fontStyleList = {"", "normal", "italic", "oblique"};
	private JComboBox fontStyleCombo = createCombo(fontStyleList, TT_FONT_STYLE);

	private String[] fontVariantList = {"", "normal", "small-caps"};
	private JComboBox fontVariantCombo = createCombo(fontVariantList, TT_FONT_VARIANT);

	private String[] fontWeightList = {"", "normal", "bold", "bolder", "lighter", "100", "200", "300", "400", "500", "600", "700", "800", "900"};
	private JComboBox fontWeightCombo = createCombo(fontWeightList, TT_FONT_WEIGHT);


	/**
	 * Constructor for the CssBorder object
	 *
	 * @param editor  Description of the Parameter
	 */
	public Font(EditorFrame editor) {
		super(editor);

		setLayout(new BorderLayout());
		top.setLayout(new BoxLayout(top, BoxLayout.Y_AXIS));
		top.setBorder(BorderFactory.createTitledBorder("Font"));

		setBackground(Color.white);
		top.setBackground(Color.white);
		center.setBackground(Color.white);

		fields.put("font", fontCombo);
		fields.put("font-family", fontFamilyCombo);
		fields.put("font-size", fontSizeCombo);
		fields.put("font-size-adjust", fontSizeAdjustCombo);
		fields.put("font-stretch", fontStretchCombo);
		fields.put("font-style", fontStyleCombo);
		fields.put("font-variant", fontVariantCombo);
		fields.put("font-weight", fontWeightCombo);

		links.put("font", "http://www.w3schools.com/css/pr_font_font.asp");
		links.put("font-family", "http://www.w3schools.com/css/pr_font_font-family.asp");
		links.put("font-size", "http://www.w3schools.com/css/pr_font_font-size.asp");
		links.put("font-size-adjust", "http://www.w3schools.com/css/pr_font_font-size-adjust.asp");
		links.put("font-stretch", "http://www.w3schools.com/css/pr_font_font-stretch.asp");
		links.put("font-style", "http://www.w3schools.com/css/pr_font_font-style.asp");
		links.put("font-variant", "http://www.w3schools.com/css/pr_font_font-variant.asp");
		links.put("font-weight", "http://www.w3schools.com/css/pr_font_weight.asp");
		
		fontFamilyCombo.addActionListener(new FontListener(this, "Choose fonts", "fonts..."));
		fontSizeCombo.addActionListener(new PercentListener(this, "Choose font size", "percent..."));
		fontSizeCombo.addActionListener(new SizeUnitListener(this, "Choose font size", "length..."));
		fontSizeAdjustCombo.addActionListener(new SizeListener(this, "Choose font size adjust", "number..."));

		addComponents(top);
		add(top, BorderLayout.NORTH);
		add(center, BorderLayout.CENTER);
	}


	/**
	 * Gets the fontFamilyNames attribute of the Font class
	 *
	 * @return   The fontFamilyNames value
	 */
	public static String[] getFontFamilyNames() {
		String[] fontNames = new String[fontFamilyList.length - 2];
		for (int i = 2; i < fontFamilyList.length; i++) {
			fontNames[i - 2] = fontFamilyList[i];
		}
		return fontNames;
	}
}

