package net.java.dev.csseditor.tabs;

import java.awt.BorderLayout;
import java.awt.Color;

import javax.swing.BorderFactory;
import javax.swing.BoxLayout;
import javax.swing.JComboBox;
import javax.swing.JPanel;

import net.java.dev.csseditor.EditorFrame;
import net.java.dev.csseditor.listeners.FileListener;
import net.java.dev.csseditor.listeners.SizeUnitListener;

/**
 * Diplays a panel that allows users to manipulate css background properties
 *
 * @author   <a href="mailto:uzi@landsmanns.com">Uzi Landsmann</a>
 */
public class List extends AbstractTabPanel {

	private JPanel top = new JPanel();
	private JPanel center = new JPanel();

	private String[] listStyleList = {""};
	private JComboBox listStyleCombo = createCombo(listStyleList, TT_LIST_STYLE);

	private String[] listStyleImageList = {"", "file...", "none"};
	private JComboBox listStyleImageCombo = createCombo(listStyleImageList, TT_LIST_STYLE_IMAGE);

	private String[] listStylePositionList = {"", "inside", "outside"};
	private JComboBox listStylePositionCombo = createCombo(listStylePositionList, TT_LIST_STYLE_POSITION);

	private String[] listStyleTypeList = {"", "none", "disc", "circle", "square", "decimal", "decimal-leading-zero", "lower-roman", "upper-roman", "lower-alpha", "upper-alpha", "lower-greek", "lower-latin", "upper-latin", "hebrew", "armenian", "georgian", "cjk-ideographic", "hiragana", "katakana", "hiragana-iroha", "katakana-iroha"};
	private JComboBox listStyleTypeCombo = createCombo(listStyleTypeList, TT_LIST_STYLE_TYPE);

	private String[] markerOffsetList = {"", "length...", "auto"};
	private JComboBox markerOffsetCombo = createCombo(markerOffsetList, TT_MARKER_OFFSET);


	/**
	 * Constructor for the CssBorder object
	 *
	 * @param editor  Description of the Parameter
	 */
	public List(EditorFrame editor) {
		super(editor);

		setLayout(new BorderLayout());
		top.setLayout(new BoxLayout(top, BoxLayout.Y_AXIS));
		top.setBorder(BorderFactory.createTitledBorder("List style"));

		setBackground(Color.white);
		top.setBackground(Color.white);
		center.setBackground(Color.white);

		fields.put("list-style", listStyleCombo);
		fields.put("list-style-image", listStyleImageCombo);
		fields.put("list-style-position", listStylePositionCombo);
		fields.put("list-style-type", listStyleTypeCombo);
		fields.put("marker-offset", markerOffsetCombo);
		
		links.put("list-style", "http://www.w3schools.com/css/pr_list-style.asp");
		links.put("list-style-image", "http://www.w3schools.com/css/pr_list-style-image.asp");
		links.put("list-style-position", "http://www.w3schools.com/css/pr_list-style-position.asp");
		links.put("list-style-type", "http://www.w3schools.com/css/pr_list-style-type.asp");
		links.put("marker-offset", "");

		listStyleImageCombo.addActionListener(new FileListener(this, "Choose file", "file..."));
		markerOffsetCombo.addActionListener(new SizeUnitListener(this, "Choose marker offset", "length..."));

		addComponents(top);
		add(top, BorderLayout.NORTH);
		add(center, BorderLayout.CENTER);
	}
}

