package net.java.dev.csseditor.tabs;

import java.awt.BorderLayout;
import java.awt.Color;

import javax.swing.BorderFactory;
import javax.swing.BoxLayout;
import javax.swing.JComboBox;
import javax.swing.JPanel;

import net.java.dev.csseditor.EditorFrame;
import net.java.dev.csseditor.listeners.PercentListener;
import net.java.dev.csseditor.listeners.SizeUnitListener;

/**
 * Diplays a panel that allows users to manipulate css background properties
 *
 * @author   <a href="mailto:uzi@landsmanns.com">Uzi Landsmann</a>
 */
public class Margin extends AbstractTabPanel {

	private JPanel top = new JPanel();
	private JPanel center = new JPanel();

	private String[] marginList = {"", "auto", "percent...", "length..."};
	private JComboBox marginCombo = createCombo(marginList, TT_MARGIN);

	private String[] marginBottomList = {"", "auto", "percent...", "length..."};
	private JComboBox marginBottomCombo = createCombo(marginBottomList, TT_MARGIN_BOTTOM);

	private String[] marginLeftList = {"", "auto", "percent...", "length..."};
	private JComboBox marginLeftCombo = createCombo(marginLeftList, TT_MARGIN_LEFT);

	private String[] marginTopList = {"", "auto", "percent...", "length..."};
	private JComboBox marginTopCombo = createCombo(marginTopList, TT_MARGIN_TOP);

	private String[] marginRightList = {"", "auto", "percent...", "length..."};
	private JComboBox marginRightCombo = createCombo(marginRightList, TT_MARGIN_RIGHT);


	/**
	 * Constructor for the CssBorder object
	 *
	 * @param editor  Description of the Parameter
	 */
	public Margin(EditorFrame editor) {
		super(editor);

		setLayout(new BorderLayout());
		top.setLayout(new BoxLayout(top, BoxLayout.Y_AXIS));
		top.setBorder(BorderFactory.createTitledBorder("Margin"));

		setBackground(Color.white);
		top.setBackground(Color.white);
		center.setBackground(Color.white);

		fields.put("margin", marginCombo);
		fields.put("margin-bottom", marginBottomCombo);
		fields.put("margin-left", marginLeftCombo);
		fields.put("margin-top", marginTopCombo);
		fields.put("margin-right", marginRightCombo);

		links.put("margin", "http://www.w3schools.com/css/pr_margin.asp");
		links.put("margin-bottom", "http://www.w3schools.com/css/pr_margin-bottom.asp");
		links.put("margin-left", "http://www.w3schools.com/css/pr_margin-left.asp");
		links.put("margin-top", "http://www.w3schools.com/css/pr_margin-top.asp");
		links.put("margin-right", "http://www.w3schools.com/css/pr_margin-right.asp");

		marginCombo.addActionListener(new PercentListener(this, "Choose width", "percent..."));
		marginCombo.addActionListener(new SizeUnitListener(this, "Choose width", "length..."));

		marginBottomCombo.addActionListener(new PercentListener(this, "Choose width", "percent..."));
		marginBottomCombo.addActionListener(new SizeUnitListener(this, "Choose width", "length..."));

		marginLeftCombo.addActionListener(new PercentListener(this, "Choose width", "percent..."));
		marginLeftCombo.addActionListener(new SizeUnitListener(this, "Choose width", "length..."));

		marginTopCombo.addActionListener(new PercentListener(this, "Choose width", "percent..."));
		marginTopCombo.addActionListener(new SizeUnitListener(this, "Choose width", "length..."));

		marginRightCombo.addActionListener(new PercentListener(this, "Choose width", "percent..."));
		marginRightCombo.addActionListener(new SizeUnitListener(this, "Choose width", "length..."));

		addComponents(top);
		add(top, BorderLayout.NORTH);
		add(center, BorderLayout.CENTER);
	}
}

