package net.java.dev.csseditor.tabs;

import java.awt.BorderLayout;
import java.awt.Color;

import javax.swing.BorderFactory;
import javax.swing.BoxLayout;
import javax.swing.JComboBox;
import javax.swing.JPanel;

import net.java.dev.csseditor.EditorFrame;
import net.java.dev.csseditor.listeners.ColorListener;
import net.java.dev.csseditor.listeners.SizeUnitListener;

/**
 * Diplays a panel that allows users to manipulate css background properties
 *
 * @author   <a href="mailto:uzi@landsmanns.com">Uzi Landsmann</a>
 */
public class Outline extends AbstractTabPanel {

	private JPanel top = new JPanel();
	private JPanel center = new JPanel();

	private String[] outlineList = {""};
	private JComboBox outlineCombo = createCombo(outlineList, TT_OUTLINE);

	private String[] outlineColorList = new String[colorList.length + 1];
	private JComboBox outlineColorCombo;

	private String[] outlineStyleList = {"", "none", "dotted", "dashed", "solid", "double", "groove", "ridge", "inset", "outset"};
	private JComboBox outlineStyleCombo = createCombo(outlineStyleList, TT_OUTLINE_STYLE);

	private String[] outlineWidthList = {"", "length...", "thin", "medium", "thick"};
	private JComboBox outlineWidthCombo = createCombo(outlineWidthList, TT_OUTLINE_WIDTH);


	/**
	 * Constructor for the CssBorder object
	 *
	 * @param editor  Description of the Parameter
	 */
	public Outline(EditorFrame editor) {
		super(editor);

		setLayout(new BorderLayout());
		top.setLayout(new BoxLayout(top, BoxLayout.Y_AXIS));
		top.setBorder(BorderFactory.createTitledBorder("Outline"));

		setBackground(Color.white);
		top.setBackground(Color.white);
		center.setBackground(Color.white);

		int i;
		for (i = 0; i < colorList.length; i++) {
			outlineColorList[i] = colorList[i];
		}
		outlineColorList[i] = "invert";
		outlineColorCombo = createCombo(outlineColorList, TT_OUTLINE_COLOR);

		fields.put("outline-color", outlineColorCombo);
		fields.put("outline-style", outlineStyleCombo);
		fields.put("outline-width", outlineWidthCombo);

		links.put("outline-color", "http://www.w3schools.com/css/pr_outline-color.asp");
		links.put("outline-style", "http://www.w3schools.com/css/pr_outline-style.asp");
		links.put("outline-width", "http://www.w3schools.com/css/pr_outline-width.asp");

		outlineColorCombo.addActionListener(new ColorListener(this, "Choose color", "color..."));
		outlineWidthCombo.addActionListener(new SizeUnitListener(this, "Choose width", "length..."));

		addComponents(top);
		add(top, BorderLayout.NORTH);
		add(center, BorderLayout.CENTER);
	}
}

