package net.java.dev.csseditor.tabs;

import java.awt.BorderLayout;
import java.awt.Color;

import javax.swing.BorderFactory;
import javax.swing.BoxLayout;
import javax.swing.JComboBox;
import javax.swing.JPanel;

import net.java.dev.csseditor.EditorFrame;
import net.java.dev.csseditor.listeners.PercentListener;
import net.java.dev.csseditor.listeners.SizeUnitListener;

/**
 * Diplays a panel that allows users to manipulate css background properties
 *
 * @author   <a href="mailto:uzi@landsmanns.com">Uzi Landsmann</a>
 */
public class Padding extends AbstractTabPanel {

	private JPanel top = new JPanel();
	private JPanel center = new JPanel();

	private String[] paddingList = {"", "percent...", "length..."};
	private JComboBox paddingCombo = createCombo(paddingList, TT_PADDING);

	private String[] paddingBottomList = {"", "percent...", "length..."};
	private JComboBox paddingBottomCombo = createCombo(paddingBottomList, TT_PADDING_BOTTOM);

	private String[] paddingLeftList = {"", "percent...", "length..."};
	private JComboBox paddingLeftCombo = createCombo(paddingLeftList, TT_PADDING_LEFT);

	private String[] paddingTopList = {"", "percent...", "length..."};
	private JComboBox paddingTopCombo = createCombo(paddingTopList, TT_PADDING_TOP);

	private String[] paddingRightList = {"", "percent...", "length..."};
	private JComboBox paddingRightCombo = createCombo(paddingRightList, TT_PADDING_RIGHT);


	/**
	 * Constructor for the CssBorder object
	 *
	 * @param editor  Description of the Parameter
	 */
	public Padding(EditorFrame editor) {
		super(editor);

		setLayout(new BorderLayout());
		top.setLayout(new BoxLayout(top, BoxLayout.Y_AXIS));
		top.setBorder(BorderFactory.createTitledBorder("Padding"));

		setBackground(Color.white);
		top.setBackground(Color.white);
		center.setBackground(Color.white);

		fields.put("padding", paddingCombo);
		fields.put("padding-bottom", paddingBottomCombo);
		fields.put("padding-left", paddingLeftCombo);
		fields.put("padding-right", paddingRightCombo);
		fields.put("padding-top", paddingTopCombo);

		links.put("padding", "http://www.w3schools.com/css/pr_padding.asp");
		links.put("padding-bottom", "http://www.w3schools.com/css/pr_padding-bottom.asp");
		links.put("padding-left", "http://www.w3schools.com/css/pr_padding-left.asp");
		links.put("padding-right", "http://www.w3schools.com/css/pr_padding-right.asp");
		links.put("padding-top", "http://www.w3schools.com/css/pr_padding-top.asp");

		paddingCombo.addActionListener(new PercentListener(this, "Choose padding", "percent..."));
		paddingCombo.addActionListener(new SizeUnitListener(this, "Choose padding", "length..."));

		paddingBottomCombo.addActionListener(new PercentListener(this, "Choose bottom padding", "percent..."));
		paddingBottomCombo.addActionListener(new SizeUnitListener(this, "Choose bottom padding", "length..."));

		paddingLeftCombo.addActionListener(new PercentListener(this, "Choose left padding", "percent..."));
		paddingLeftCombo.addActionListener(new SizeUnitListener(this, "Choose left padding", "length..."));

		paddingTopCombo.addActionListener(new PercentListener(this, "Choose top padding", "percent..."));
		paddingTopCombo.addActionListener(new SizeUnitListener(this, "Choose top padding", "length..."));

		paddingRightCombo.addActionListener(new PercentListener(this, "Choose right padding", "percent..."));
		paddingRightCombo.addActionListener(new SizeUnitListener(this, "Choose right padding", "length..."));

		addComponents(top);
		add(top, BorderLayout.NORTH);
		add(center, BorderLayout.CENTER);
	}
}

