package net.java.dev.csseditor.tabs;

import java.awt.BorderLayout;
import java.awt.Color;

import javax.swing.BorderFactory;
import javax.swing.BoxLayout;
import javax.swing.JComboBox;
import javax.swing.JPanel;

import net.java.dev.csseditor.EditorFrame;
import net.java.dev.csseditor.listeners.PercentListener;
import net.java.dev.csseditor.listeners.ShapeListener;
import net.java.dev.csseditor.listeners.SizeListener;
import net.java.dev.csseditor.listeners.SizeUnitListener;

/**
 * Diplays a panel that allows users to manipulate css background properties
 *
 * @author   <a href="mailto:uzi@landsmanns.com">Uzi Landsmann</a>
 */
public class Position extends AbstractTabPanel {

	private JPanel top = new JPanel();
	private JPanel center = new JPanel();

	private String[] bottomList = {"", "percent...", "length...", "auto"};
	private JComboBox bottomCombo = createCombo(bottomList, TT_BOTTOM);

	private String[] clipList = {"", "shape...", "auto"};
	private JComboBox clipCombo = createCombo(clipList, TT_CLIP);

	private String[] leftList = {"", "percent...", "length...", "auto"};
	private JComboBox leftCombo = createCombo(leftList, TT_LEFT);

	private String[] overflowList = {"", "visible", "hidden", "scroll", "auto"};
	private JComboBox overflowCombo = createCombo(overflowList, TT_OVERFLOW);

	private String[] rightList = {"", "percent...", "length...", "auto"};
	private JComboBox rightCombo = createCombo(rightList, TT_RIGHT);

	private String[] topList = {"", "percent...", "length...", "auto"};
	private JComboBox topCombo = createCombo(topList, TT_TOP);

	private String[] verticalAlignList = {"", "percent...", "length...", "baseline", "sub", "super", "top", "text-top", "middle", "bottom", "text-bottom"};
	private JComboBox verticalAlignCombo = createCombo(verticalAlignList, TT_VERTICAL_ALIGN);

	private String[] zIndexList = {"", "number...", "auto"};
	private JComboBox zIndexCombo = createCombo(zIndexList, TT_Z_INDEX);


	/**
	 * Constructor for the CssBorder object
	 *
	 * @param editor  Description of the Parameter
	 */
	public Position(EditorFrame editor) {
		super(editor);

		setLayout(new BorderLayout());
		top.setLayout(new BoxLayout(top, BoxLayout.Y_AXIS));
		top.setBorder(BorderFactory.createTitledBorder("Position"));

		setBackground(Color.white);
		top.setBackground(Color.white);
		center.setBackground(Color.white);

		fields.put("bottom", bottomCombo);
		fields.put("clip", clipCombo);
		fields.put("left", leftCombo);
		fields.put("overflow", overflowCombo);
		fields.put("right", rightCombo);
		fields.put("top", topCombo);
		fields.put("vertical-align", verticalAlignCombo);
		fields.put("z-index", zIndexCombo);

		links.put("bottom", "http://www.w3schools.com/css/pr_pos_bottom.asp");
		links.put("clip", "http://www.w3schools.com/css/pr_pos_clip.asp");
		links.put("left", "http://www.w3schools.com/css/pr_pos_left.asp");
		links.put("overflow", "http://www.w3schools.com/css/pr_pos_overflow.asp");
		links.put("right", "http://www.w3schools.com/css/pr_pos_right.asp");
		links.put("top", "http://www.w3schools.com/css/pr_pos_top.asp");
		links.put("vertical-align", "http://www.w3schools.com/css/pr_pos_vertical-align.asp");
		links.put("z-index", "http://www.w3schools.com/css/pr_pos_z-index.asp");

		bottomCombo.addActionListener(new PercentListener(this, "Choose bottom position", "percent..."));
		bottomCombo.addActionListener(new SizeUnitListener(this, "Choose bottom position", "length..."));

		clipCombo.addActionListener(new ShapeListener(this, "Choose clip shape", "shape..."));

		leftCombo.addActionListener(new PercentListener(this, "Choose left position", "percent..."));
		leftCombo.addActionListener(new SizeUnitListener(this, "Choose left position", "length..."));

		rightCombo.addActionListener(new PercentListener(this, "Choose right position", "percent..."));
		rightCombo.addActionListener(new SizeUnitListener(this, "Choose right position", "length..."));

		topCombo.addActionListener(new PercentListener(this, "Choose top position", "percent..."));
		topCombo.addActionListener(new SizeUnitListener(this, "Choose top position", "length..."));

		verticalAlignCombo.addActionListener(new PercentListener(this, "Choose vertical alignment", "percent..."));
		verticalAlignCombo.addActionListener(new SizeUnitListener(this, "Choose vertical alignment", "length..."));

		zIndexCombo.addActionListener(new SizeListener(this, "Choose z index", "number..."));

		addComponents(top);
		add(top, BorderLayout.NORTH);
		add(center, BorderLayout.CENTER);
	}
}

