package net.java.dev.csseditor.tabs;

import java.awt.BorderLayout;
import java.awt.Color;

import javax.swing.BorderFactory;
import javax.swing.BoxLayout;
import javax.swing.JComboBox;
import javax.swing.JPanel;

import net.java.dev.csseditor.EditorFrame;
import net.java.dev.csseditor.listeners.DoubleSizeUnitListener;

/**
 * Diplays a panel that allows users to manipulate css background properties
 *
 * @author   <a href="mailto:uzi@landsmanns.com">Uzi Landsmann</a>
 */
public class Table extends AbstractTabPanel {

	private JPanel top = new JPanel();
	private JPanel center = new JPanel();

	private String[] borderCollapseList = {"", "collapse", "separate"};
	private JComboBox borderCollapseCombo = createCombo(borderCollapseList, TT_BORDER_COLLAPSE);

	private String[] borderSpacingList = {"", "length..."};
	private JComboBox borderSpacingCombo = createCombo(borderSpacingList, TT_BORDER_SPACING);

	private String[] captionSideList = {"", "top", "bottom", "left", "right"};
	private JComboBox captionSideCombo = createCombo(captionSideList, TT_CAPTION_SIDE);

	private String[] emptyCellsList = {"", "show", "hide"};
	private JComboBox emptyCellsCombo = createCombo(emptyCellsList, TT_EMPTY_CELLS);

	private String[] tableLayoutList = {"", "auto", "fixed"};
	private JComboBox tableLayoutCombo = createCombo(tableLayoutList, TT_TABLE_LAYOUT);


	/**
	 * Constructor for the CssBorder object
	 *
	 * @param editor  Description of the Parameter
	 */
	public Table(EditorFrame editor) {
		super(editor);

		setLayout(new BorderLayout());
		top.setLayout(new BoxLayout(top, BoxLayout.Y_AXIS));
		top.setBorder(BorderFactory.createTitledBorder("Table"));

		setBackground(Color.white);
		top.setBackground(Color.white);
		center.setBackground(Color.white);

		fields.put("border-collapse", borderCollapseCombo);
		fields.put("border-spacing", borderSpacingCombo);
		fields.put("caption-side", captionSideCombo);
		fields.put("empty-cells", emptyCellsCombo);
		fields.put("table-layout", tableLayoutCombo);

		links.put("border-collapse", "http://www.w3schools.com/css/pr_tab_border-collapse.asp");
		links.put("border-spacing", "http://www.w3schools.com/css/css_reference.asp#table");
		links.put("caption-side", "http://www.w3schools.com/css/css_reference.asp#table");
		links.put("empty-cells", "http://www.w3schools.com/css/css_reference.asp#table");
		links.put("table-layout", "http://www.w3schools.com/css/css_reference.asp#table");

		borderSpacingCombo.addActionListener(new DoubleSizeUnitListener(this, "Choose border spacing", "length..."));

		addComponents(top);
		add(top, BorderLayout.NORTH);
		add(center, BorderLayout.CENTER);
	}
}

