package net.java.dev.csseditor.tabs;

import java.awt.BorderLayout;
import java.awt.Color;

import javax.swing.BorderFactory;
import javax.swing.BoxLayout;
import javax.swing.JComboBox;
import javax.swing.JPanel;

import net.java.dev.csseditor.EditorFrame;
import net.java.dev.csseditor.listeners.ColorListener;
import net.java.dev.csseditor.listeners.PercentListener;
import net.java.dev.csseditor.listeners.SizeUnitListener;
import net.java.dev.csseditor.tabs.AbstractTabPanel;

/**
 * Diplays a panel that allows users to manipulate css background properties
 *
 * @author   <a href="mailto:uzi@landsmanns.com">Uzi Landsmann</a>
 */
public class Text extends AbstractTabPanel {

	private JPanel top = new JPanel();
	private JPanel center = new JPanel();

	private JComboBox colorCombo = createCombo(colorList, TT_COLOR);

	private String[] directionList = {"", "ltr", "rtl"};
	private JComboBox directionCombo = createCombo(directionList, TT_DIRECTION);

	private String[] letterSpacingList = {"", "length...", "normal"};
	private JComboBox letterSpacingCombo = createCombo(letterSpacingList, TT_LETTER_SPACING);

	private String[] textAlignList = {"", "left", "right", "center", "justify"};
	private JComboBox textAlignCombo = createCombo(textAlignList, TT_TEXT_ALIGN);

	private String[] textDecorationList = {"", "none", "underline", "overline", "line-through", "blink"};
	private JComboBox textDecorationCombo = createCombo(textDecorationList, TT_TEXT_DECORATION);

	private String[] textIndentList = {"", "length...", "percent..."};
	private JComboBox textIndentCombo = createCombo(textIndentList, TT_TEXT_INDENT);

	private String[] textShadowList = {"", "color...", "length...", "none"};
	private JComboBox textShadowCombo = createCombo(textShadowList, TT_TEXT_SHADOW);

	private String[] textTransformList = {"", "none", "capitalize", "uppercase", "lowercase"};
	private JComboBox textTransformCombo = createCombo(textTransformList, TT_TEXT_TRANSFORM);

	private String[] unicodeBidiList = {"", "normal", "embed", "bidi-override"};
	private JComboBox unicodeBidiCombo = createCombo(unicodeBidiList, TT_UNICODE_BIDI);

	private String[] whiteSpaceList = {"", "normal", "pre", "nowrap"};
	private JComboBox whiteSpaceCombo = createCombo(whiteSpaceList, TT_WHITE_SPACE);

	private String[] wordSpacingList = {"", "length...", "normal"};
	private JComboBox wordSpacingCombo = createCombo(wordSpacingList, TT_WORD_SPACING);


	/**
	 * Constructor for the CssBorder object
	 *
	 * @param editor  Description of the Parameter
	 */
	public Text(EditorFrame editor) {
		super(editor);

		setLayout(new BorderLayout());
		top.setLayout(new BoxLayout(top, BoxLayout.Y_AXIS));
		top.setBorder(BorderFactory.createTitledBorder("Text"));

		setBackground(Color.white);
		top.setBackground(Color.white);
		center.setBackground(Color.white);

		fields.put("color", colorCombo);
		fields.put("direction", directionCombo);
		fields.put("letter-spacing", letterSpacingCombo);
		fields.put("text-align", textAlignCombo);
		fields.put("text-decoration", textDecorationCombo);
		fields.put("text-indent", textIndentCombo);
		fields.put("text-shadow", textShadowCombo);
		fields.put("text-transform", textTransformCombo);
		fields.put("unicode-bidi", unicodeBidiCombo);
		fields.put("white-space", whiteSpaceCombo);
		fields.put("word-spacing", wordSpacingCombo);

		links.put("color", "http://www.w3schools.com/css/pr_text_color.asp");
		links.put("direction", "http://www.w3schools.com/css/pr_text_direction.asp");
		links.put("letter-spacing", "http://www.w3schools.com/css/pr_text_letter-spacing.asp");
		links.put("text-align", "http://www.w3schools.com/css/pr_text_text-align.asp");
		links.put("text-decoration", "http://www.w3schools.com/css/pr_text_text-decoration.asp");
		links.put("text-indent", "http://www.w3schools.com/css/pr_text_text-indent.asp");
		links.put("text-shadow", "");
		links.put("text-transform", "http://www.w3schools.com/css/pr_text_text-transform.asp");
		links.put("unicode-bidi", "");
		links.put("white-space", "http://www.w3schools.com/css/pr_text_white-space.asp");
		links.put("word-spacing", "http://www.w3schools.com/css/pr_text_word-spacing.asp");

		colorCombo.addActionListener(new ColorListener(this, "Choose color", "color..."));
		letterSpacingCombo.addActionListener(new SizeUnitListener(this, "Choose letter spacing", "length..."));
		textIndentCombo.addActionListener(new SizeUnitListener(this, "Choose text indent", "length..."));
		textIndentCombo.addActionListener(new PercentListener(this, "Choose text indent", "percent..."));
		textShadowCombo.addActionListener(new ColorListener(this, "Choose shadow color", "color..."));
		textShadowCombo.addActionListener(new SizeUnitListener(this, "Choose text indent", "length..."));
		wordSpacingCombo.addActionListener(new SizeUnitListener(this, "Choose word spacing", "length..."));

		addComponents(top);
		add(top, BorderLayout.NORTH);
		add(center, BorderLayout.CENTER);
	}
}

